@@ -45,10 +45,10 @@ $LANG01 = array(
     2 => 'lees verder',
     3 => 'kommentaar',
     4 => 'Wysig',
-    5 => 'Stem',
-    6 => 'Resultaat',
+    5 => '',
+    6 => '',
     7 => '',
-    8 => 'stemme',
+    8 => '',
     9 => 'Admin Funksies:',
     10 => 'Bydraes',
     11 => 'Artikels',
@@ -80,7 +80,7 @@ $LANG01 = array(
     37 => 'Geen gebruiker artikels',
     38 => 'Inhoud Sindikasie',
     39 => 'Herlaai',
-    40 => 'Jou <tt>register_globals = Off</tt> in jou <tt>php.ini</tt>. Geekolog vereis egter dat <tt>register_globals</tt> <strong>aan</strong> is. Voordat jy verder gaan, stel dit na <strong>on</strong> en herlaai jou webblaaier.',
+    40 => '',
     41 => 'Besoekers',
     42 => 'Geskryf deur:',
     43 => 'Antwoord hierop',
@@ -151,7 +151,7 @@ $LANG01 = array(
     108 => 'Vee Kas skoon',
     109 => 'Meld misbruik aan',
     110 => 'Rapporteer hierdie plasing aan die werfadmin',
-    111 => 'Vertoon PDF Weergawe',
+    111 => '',
     112 => 'Geregistreerde Gebruikers',
     113 => 'Dokumentasie',
     114 => 'TRACKBACKS',
@@ -203,7 +203,24 @@ $LANG03 = array(
     24 => 'Anonieme Gebruiker',
     25 => 'Is jy seker dat jy hierdie plasing aan die werf admin wil rapporteer?',
     26 => '%s het die volgende beledigende plasing of misbruik gerapporteer:',
-    27 => 'Misbruikverslag'
+    27 => 'Misbruikverslag',
+    28 => 'Preview Changes',
+    29 => 'Submit Changes',
+    30 => 'Edited on',
+    31 => 'by',
+    32 => 'Editing a Comment',
+    33 => 'Editing a Comment Submission',
+    34 => 'Preview Submission Changes',
+    35 => 'Save Changes to Queue',
+    36 => 'Notify me of new replies',
+    37 => 'New Comment Reply',
+    38 => 'A reply has been made to your comment \'%s\'.',
+    39 => 'You may view the comment thread at the following address:',
+    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
+    41 => 'Hello %s,',
+    42 => 'Unsubscribe',
+    43 => 'Unsubscribe from reply notifications',
+    44 => 'Your Name'
 );
 
 ###############################################################################
@@ -349,7 +366,7 @@ $LANG04 = array(
     137 => 'Filter Story Content',
     138 => 'Misc Settings',
     139 => 'Layout and Language',
-    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics<li>Set the maximum number of stories to show per page</li><li>Set your theme and perferred date format</li>',
+    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
     141 => 'Privacy Settings',
     142 => 'The default setting is to allow users & admins to email fellow site members and show your status as online. Un-check these options to protect your privacy.',
     143 => 'Filter Block Content',
@@ -363,7 +380,13 @@ $LANG04 = array(
     156 => 'Delete Account',
     157 => 'Delete Option',
     158 => 'Time Zone',
-    159 => 'This email was generated automatically. Please do not reply to this email.'
+    159 => 'This email was generated automatically. Please do not reply to this email.',
+    160 => '(max. %d x %d pixels, %d bytes; %s)',
+    161 => 'will be scaled down',
+    162 => 'will not be scaled',
+    163 => 'Re-Authentication Failed',
+    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
+    165 => 'Use Advanced Editor'
 );
 
 ###############################################################################
@@ -431,7 +454,10 @@ $LANG08 = array(
     32 => 'Datum',
     33 => 'Lees die volledige artikel by',
     34 => 'Einde van Boodskap',
-    35 => 'Jammer, hierdie gebruiker verkies om nie epos te ontvang nie.'
+    35 => 'Jammer, hierdie gebruiker verkies om nie epos te ontvang nie.',
+    36 => 'Copy:',
+    37 => 'Send me a copy of this email',
+    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
 );
 
 ###############################################################################
@@ -498,7 +524,18 @@ $LANG09 = array(
     58 => 'Meer resultate &gt;&gt;',
     59 => 'Resultate',
     60 => 'per bladsy',
-    61 => 'Verfyn soektog'
+    61 => 'Verfyn soektog',
+    62 => '#',
+    63 => 'Description',
+    64 => 'Showing %1$d - %2$d of %3$d results',
+    65 => 'Story',
+    66 => 'Comment',
+    67 => 'Show %d Results',
+    68 => 'Sort By',
+    69 => 'Titles Only',
+    70 => 'Not available ...',
+    71 => 'asc',
+    72 => 'desc'
 );
 
 ###############################################################################
@@ -546,7 +583,8 @@ $LANG11 = array(
     2 => 'Epos Artikel aan \'n Vriend',
     3 => 'Drukbare artikelformaat',
     4 => 'Artikelopsies',
-    5 => 'PDF Artikelformaat'
+    5 => '',
+    6 => 'Subscribe to \'%s\''
 );
 
 ###############################################################################
@@ -680,7 +718,7 @@ $LANG21 = array(
     47 => '',
     48 => 'Bloknaam',
     49 => ' (geen spasies en moet uniek wees)',
-    50 => '',
+    50 => 'The Block Name can not be empty',
     51 => 'sluit http:// in',
     52 => 'As jy hierdie leeg los sal die hulp-ikoon vir hierdie blok nie vertoon word nie',
     53 => 'Geaktiveer',
@@ -767,7 +805,7 @@ $LANG24 = array(
     60 => '',
     61 => 'Outo-argief',
     62 => 'Outo-verwydering',
-    63 => '',
+    63 => 'Disable Comments',
     64 => '',
     65 => '',
     66 => '',
@@ -792,7 +830,10 @@ $LANG24 = array(
     85 => 'Wys Alles',
     86 => 'Advanced Editor',
     87 => 'Story Stats',
-    88 => 'Wiki-style format'
+    88 => 'Wiki-style format',
+    89 => 'Meta Description',
+    90 => 'Meta Keywords',
+    91 => 'You can always hit "Preview" to extend the expiry time.'
 );
 
 ###############################################################################
@@ -827,7 +868,8 @@ $LANG27 = array(
     26 => 'maak hierdie die standaard onderwerp vir die artikelargief. Slegs een onderwerp toegelaat.',
     27 => 'of Laai Onderwerp Ikoon',
     28 => 'Maksimum',
-    29 => 'L&ecirc;er Oplaai Foute'
+    29 => 'L&ecirc;er Oplaai Foute',
+    30 => 'Stories in Topic'
 );
 
 ###############################################################################
@@ -918,7 +960,12 @@ $LANG28 = array(
     82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
     83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
     84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
-    85 => 'If you have forgotten the password use the following link: %s'
+    85 => 'If you have forgotten the password use the following link: %s',
+    86 => 'Include',
+    87 => 'Reminders',
+    88 => 'Default Group',
+    89 => 'Check to make this a default group for new users',
+    90 => 'Apply "Default Group" change to existing user accounts'
 );
 
 ###############################################################################
@@ -940,11 +987,14 @@ $LANG29 = array(
     18 => 'Epos',
     34 => 'Bestuur en Beheer',
     35 => 'Artikel Bydraes',
-    36 => '',
+    36 => 'Parent or Comment',
     37 => '',
     38 => 'Stuur',
     39 => 'Daar is geen bydraes op hierdie tydstip wat aksie vereis nie',
-    40 => 'Gebruikersbydraes'
+    40 => 'Gebruikersbydraes',
+    41 => 'Comment Submissions',
+    42 => 'Username',
+    43 => 'Auto-publish Comments?'
 );
 
 ###############################################################################
@@ -1020,7 +1070,21 @@ $LANG32 = array(
     35 => 'Wysig',
     36 => 'Kode',
     37 => 'Data',
-    38 => 'Opdateer!'
+    38 => 'Opdateer!',
+    39 => 'Upload a plugin',
+    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
+    41 => 'Upload',
+    42 => 'Click to update',
+    99 => 'An unknown error occured',
+    100 => 'Ok.',
+    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
+    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
+    103 => 'The uploaded file was only partially uploaded.',
+    104 => 'No file was uploaded.',
+    105 => '(undefined error)',
+    106 => 'Missing a temporary folder.',
+    107 => 'Failed to write file to disk.',
+    108 => 'File upload stopped by extension.'
 );
 
 ###############################################################################
@@ -1058,7 +1122,7 @@ $LANG33 = array(
     34 => 'Inskrywings',
     35 => 'Ure',
     36 => 'Kies jou soort nuusvoer',
-    37 => 'U het ten minste een prop ge&iuml;nstalleer wat inhoudsindikasie ondersteun. Hieronder moet u kies of u \'n Geeklog nuusvoer wil h&ecirc; of \'n voer vanaf een van die proppe.',
+    37 => '',
     38 => 'Fout: Vermiste Velde',
     39 => 'Vul asseblief die Nuusvoer se Titel, Beskrywing en L&ecirc;ernaam in.',
     40 => 'Vul asseblief die aantal inskrywings of aantal ure in.',
@@ -1073,7 +1137,10 @@ $LANG33 = array(
     49 => 'Nuusvoer Logo',
     50 => "Relatief tot werf se url ({$_CONF['site_url']})",
     51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
-    52 => 'Error: existing Filename'
+    52 => 'Error: existing Filename',
+    53 => 'All Frontpage Stories',
+    54 => 'Please select the type of feed to create.',
+    55 => 'Articles'
 );
 
 ###############################################################################
@@ -1094,8 +1161,8 @@ $MESSAGE = array(
     12 => 'Die blok is suksesvol verwyder.',
     13 => 'U onderwerp is suksesvol gestoor.',
     14 => 'Die onderwerp en al sy artikels en blokke is suksesvol verwyder.',
-    15 => '',
-    16 => '',
+    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
+    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
     17 => '',
     18 => '',
     19 => '',
@@ -1108,25 +1175,25 @@ $MESSAGE = array(
     26 => '',
     27 => 'Boodskap suksesvol gestuur.',
     28 => 'Die proppie is suksesvol gestoor',
-    29 => '',
+    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
     30 => 'Toegang geweier',
-    31 => 'Jammer, u het nie toegang tot die artikel adminblad nie.  Neem kennis dat alle pogings tot ongemagtigde toegang aangeteken word',
-    32 => 'Jammer, u het nie toegang tot die onderwerp adminblad nie.  Neem kennis dat alle pogings tot ongemagtigde toegang aangeteken word',
-    33 => 'Jammer, u het nie toegang tot die blok adminblad nie.  Neem kennis dat alle pogings tot ongemagtigde toegang aangeteken word',
+    31 => '',
+    32 => '',
+    33 => '',
     34 => '',
     35 => '',
     36 => '',
-    37 => 'Jammer, u het nie toegang tot die gebruiker adminblad nie.  Neem kennis dat alle pogings tot ongemagtigde toegang aangeteken word',
-    38 => 'Jammer, u het nie toegang tot die prop adminblad nie.  Neem kennis dat alle pogings tot ongemagtigde toegang aangeteken word',
-    39 => 'Jammer, u het nie toegang tot die epos adminblad nie.  Neem kennis dat alle pogings tot ongemagtigde toegang aangeteken word',
+    37 => '',
+    38 => '',
+    39 => '',
     40 => 'Stelselboodskap',
-    41 => 'Jammer, u het nie toegang to die woordvervangingsblad nie.  Neem kennis dat alle pogings tot ongemagtigde toegang aangeteken word',
-    42 => 'U woord is suksesvol gestoor.',
-    43 => 'Die woord is suksesvol verwyder.',
+    41 => '',
+    42 => '',
+    43 => '',
     44 => 'Die prop is suksesvol gestoor!',
     45 => 'Die prop is suksesvol verwyder.',
-    46 => 'Jammer, u het nie toegang tot die databasis rugsteunfunksie nie.  Neem kennis dat alle pogings tot ongemagtigde toegang aangeteken word',
-    47 => 'Hierdie funksie werk slegs onder *nix stelsels.  Indien u wel \'n *nix bedryfstelsel gebruik is u kasgeheue suksesvol skoongevee. As u op Windows werk, moet u na l&ecirc;ers soek met die naam adodb_*.php en hulle handmatig verwyder.',
+    46 => '',
+    47 => '',
     48 => "Dankie vir u aansoek vir lidmaatskap tot {$_CONF['site_name']}. Ons span sal u aansoek nagaan.  Indien goedgekeur, sal u wagwoord gestuur word aan die epos adres wat u verskaf het.",
     49 => 'U groep is suksesvol gestoor.',
     50 => 'Die groep is suksesvol verwyder.',
@@ -1175,8 +1242,14 @@ $MESSAGE = array(
     93 => 'Database back up was successful.',
     94 => 'Backup Failed: Filesize less than 1kb',
     95 => 'There was an error.',
-    96 => 'Sorry, you do not have access to the configuration administration page.  Please note that all attempts to access unauthorized features are logged.',
-    97 => 'Not all required fields have been passed validation - default custom membership message'
+    96 => '',
+    97 => '',
+    98 => 'The plugin was successfully uploaded.',
+    99 => 'The plugin already exists.',
+    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
+    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
+    400 => 'Not all required fields have been passed validation',
+    401 => 'Please enter Fullname'
 );
 
 ###############################################################################
@@ -1263,7 +1336,26 @@ $LANG_DB_BACKUP = array(
     'size' => 'Grootte',
     'bytes' => 'Grepe',
     'total_number' => 'Totale aantal rugsteunings: %d',
-    'download' => 'Click to download this file'
+    'download' => 'Click to download this file',
+    'new_backup' => 'New Backup',
+    'delete_failure' => 'One or more backup files could not be deleted.',
+    'delete_success' => 'Backup file(s) successfully deleted.',
+    'convert_menu' => 'Convert to InnoDB',
+    'convert_title' => 'Convert to InnoDB tables',
+    'convert_button' => 'Convert',
+    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
+    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
+    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
+    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
+    'innodb_success' => 'Successfully converted tables to InnoDB.',
+    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
+    'optimize_menu' => 'Optimize Tables',
+    'optimize_title' => 'Optimize Tables',
+    'optimize_button' => 'Optimize',
+    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
+    'last_optimization' => 'Last optimization',
+    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
+    'optimize_success' => 'Successfully optimized database tables.'
 );
 
 ###############################################################################
@@ -1301,26 +1393,6 @@ $LANG_LOGIN = array(
     4 => 'Nuwe Gebruiker'
 );
 
-###############################################################################
-# pdfgenerator.php
-
-$LANG_PDF = array(
-    1 => 'Die PDF funksie is gedeaktiveer',
-    2 => 'Die verskafde dokument is nie vertaal nie.  Die dokument is ontvang maar kon nie verwerk word nie.  Maak seker dat u slegs html formaat dokument voorl&ecirc; wat aan die xHTML standaard voldoen. Neem kennis dat onnodig komplekse html dokumente nie noodwendig korrek of enigsins vertaal sal word nie. Die dokument uit u poging was 0 grepe in lengte en is verwyder. As u seker is dat u dokument behoorlik vertaal behoort te word, stuur dit weereens.',
-    3 => 'Onbekende fout tydens skep van PDF',
-    4 => 'Geen bladsy is verskaf of u wil dalk die ad-hoc PDF funksie hieronder gebruik.  As u glo dat u verkeerdelik die blad gekry het, kontak die stelseladministrateur.  Andersins kan u die onderstaande vorm gebruik om die PDF op \'n ad-hoc wyse te skep.',
-    5 => 'Besig om u dokument te laai.',
-    6 => 'Wag asseblief terwyl u dokument gelaai word.',
-    7 => 'U kan met regterknop op die onderstaande knop kliek en dan kies \'save target...\' of \'save link location...\' om \'n kopie van u dokument te stoor.',
-    8 => 'Die gegewe pad wat in die konfigurasie l&ecirc;er van die HTMLDoc program is ongeldig of di&eacute; stelsel kan dit nie uitvoer nie.  Kontak die werfadministrateur as die probleem voortduur.',
-    9 => 'PDF-Skrywer',
-    10 => 'Hierdie is die Ad-hoc PDF-skrywer hulpmiddel. Dit sal poog om enige URL wat u verskaf na \'n PDF om te skakel.  Neem kennis dat sommige web-bladsye nie korrek vertaal sal word met hierdie funksie nie.  Dit is \'n beperking van die HTMLDoc PDF-skrywer program en sulke foute moet dus nie aan die administrateur van die werf gerapporteer word nie',
-    11 => 'URL',
-    12 => 'Skryf PDF!',
-    13 => 'Die PHP konfigurasie op hierde bediener laat nie toe dat URL\'le gebruik word met die fopen() bevel nie.  Die stelseladministrateur moet die php.ini l&ecirc;er wysig en die set allow_url_fopen veranderlike na On toe stel',
-    14 => 'Die PDF wat u versoek het bestaan nie of u het probeer om onregmatiglik toegang tot \'n l&ecirc;er te verkry.'
-);
-
 ###############################################################################
 # trackback.php
 
@@ -1419,6 +1491,31 @@ $LANG_DIR = array(
     'no_articles' => 'Geen Artikels.'
 );
 
+###############################################################################
+# admin/sectest.php
+
+$LANG_SECTEST = array(
+    'sectest' => 'Geeklog Security Check',
+    'results' => 'Results of the Security Check',
+    'okay' => 'Everything seems to be in order.',
+    'please_fix' => 'Please fix the above issues before using your site!',
+    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
+    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
+    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
+    'installation' => 'installation instructions',
+    'directory' => 'directory',
+    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
+    'fix_it' => 'This is a security risk and should be fixed!',
+    'reachable' => 'Your %s is reachable from the web.',
+    'not_reachable' => 'Good! Your %s is not reachable from the web.',
+    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
+    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
+    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
+    'inst_removed' => 'Good! You seem to have removed the install directory already.',
+    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
+    'password_okay' => 'Good! You seem to have changed the default account password already.'
+);
+
 ###############################################################################
 # "What's New" Time Strings
 # 
@@ -1492,6 +1589,7 @@ $LANG_ADMIN = array(
     'create_new_adv' => 'Create New (Adv.)',
     'enabled' => 'Aktief',
     'title' => 'Titel',
+    'page_title' => 'Page Title',
     'type' => 'Tipe',
     'topic' => 'Onderwerp',
     'help_url' => 'Hulpl&ecirc;er URL',
@@ -1506,7 +1604,14 @@ $LANG_ADMIN = array(
     'records_found' => 'Records found',
     'addchild' => 'Add child',
     'list' => 'list',
-    'list_all' => 'List all'
+    'list_all' => 'List all',
+    'meta_description' => 'Meta Description',
+    'meta_keywords' => 'Meta Keywords',
+    'na' => 'N/A',
+    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
+    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
+    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
+    'authenticate' => 'Authenticate'
 );
 
 # Localisation of the texts for the various drop-down menus that are actually
@@ -1578,7 +1683,9 @@ $LANG_CONFIG = array(
     'save_changes' => 'Save Changes',
     'reset_form' => 'Reset Form',
     'changes_made' => 'Changes were successfully made to',
-    'title' => 'Configuration Manager'
+    'title' => 'Configuration Manager',
+    'disable' => 'Click to disable this option',
+    'enable' => 'Enable'
 );
 
 $LANG_configsections['Core'] = array(
@@ -1606,7 +1713,9 @@ $LANG_confignames['Core'] = array(
     'allow_mysqldump' => 'Allow MySQL Dump',
     'mysqldump_path' => 'Path of Executable',
     'mysqldump_options' => 'MySQL Dump Options',
+    'mysqldump_filename_mask' => 'Backup File Name Mask',
     'theme' => 'Theme',
+    'doctype' => 'DOCTYPE Declaration',
     'menu_elements' => 'Menu Elements',
     'path_themes' => 'Themes Path',
     'disable_new_user_registration' => 'Disable New Registrations',
@@ -1645,6 +1754,7 @@ $LANG_confignames['Core'] = array(
     'cookie_theme' => 'Theme Cookie Name',
     'cookie_language' => 'Language Cookie Name',
     'cookie_tzid' => 'Timezone Cookie Name',
+    'cookie_anon_name' => 'Anon. Username Cookie Name',
     'cookie_ip' => 'Cookies embed IP?',
     'default_perm_cookie_timeout' => 'Permanent Timeout',
     'session_cookie_timeout' => 'Session Timeout',
@@ -1652,7 +1762,6 @@ $LANG_confignames['Core'] = array(
     'cookiedomain' => 'Cookie Domain',
     'cookiesecure' => 'Cookie Secure',
     'lastlogin' => 'Record Last Login?',
-    'pdf_enabled' => 'PDF Enabled?',
     'num_search_results' => 'Number of Search Results',
     'loginrequired' => 'Login Required?',
     'submitloginrequired' => 'Submit Login Required?',
@@ -1736,6 +1845,7 @@ $LANG_confignames['Core'] = array(
     'debug_image_upload' => 'Debug Image Uploading?',
     'keep_unscaled_image' => 'Keep Unscaled Image?',
     'allow_user_scaling' => 'Allow User Scaling?',
+    'jpeg_quality' => 'JPEG Quality?',
     'max_image_width' => 'Max Image Width?',
     'max_image_height' => 'Max Image Height?',
     'max_image_size' => 'Max Image Size?',
@@ -1746,32 +1856,55 @@ $LANG_confignames['Core'] = array(
     'max_photo_height' => 'Max Photo Height?',
     'max_photo_size' => 'Max Photo Size?',
     'use_gravatar' => 'Use Gravatar?',
-    'gravatar_rating' => 'Gravatar Rating Allowed',
+    'gravatar_rating' => 'Gravatar Rating',
     'force_photo_width' => 'Force Photo Width',
     'default_photo' => 'Default Photo',
     'commentspeedlimit' => 'Comment Speed Limit',
     'comment_limit' => 'Comment Limit',
     'comment_mode' => 'Comment Mode',
     'comment_code' => 'Comment Default',
+    'comment_edit' => 'Allow Comment Edit?',
+    'comment_edittime' => 'Comment Edit Time (seconds)',
+    'commentsubmission' => 'Queue Comment Submissions',
     'passwordspeedlimit' => 'Password Speed Limit',
     'login_attempts' => 'Max. Login Attempts',
     'login_speedlimit' => 'Login Speed Limit',
     'user_html' => 'User HTML',
     'admin_html' => 'Admin HTML',
+    'advanced_html' => 'Additional HTML for Adv. Editor',
     'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
     'allowed_protocols' => 'Allowed Protocols',
-    'disable_autolinks' => 'Disable Autolinks?',
+    'disable_autolinks' => 'Disable Autotags?',
+    'clickable_links' => 'Make URLs clickable?',
+    'compressed_output' => 'Send compressed output?',
+    'frame_options' => 'Protection against "clickjacking"',
     'censormode' => 'Censor Mode?',
     'censorreplace' => 'Censor Replace Text',
     'censorlist' => 'Censor List',
     'ip_lookup' => 'IP Lookup',
     'url_rewrite' => 'Enable URL Rewrite',
+    'meta_tags' => 'Meta Tags',
+    'meta_description' => 'Default Meta Description',
+    'meta_keywords' => 'Default Meta Keywords',
     'default_permissions_block' => 'Block Default Permissions',
     'default_permissions_story' => 'Story Default Permissions',
     'default_permissions_topic' => 'Topic Default Permissions',
     'atom_max_stories' => 'Max. Stories in Webservices Feed',
     'disable_webservices' => 'Disable Webservices?',
-    'restrict_webservices' => 'Restrict Webservices?'
+    'restrict_webservices' => 'Restrict Webservices?',
+    'article_comment_close_enabled' => 'Automatically close comments (default)',
+    'article_comment_close_days' => 'Days to close comments (default)',
+    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
+    'allow_reply_notifications' => 'Allow comment reply notifications?',
+    'search_style' => 'Results List Style',
+    'search_limits' => 'Page Limits',
+    'search_show_num' => 'Show Result Number?',
+    'search_show_type' => 'Show Result Type?',
+    'search_show_sort' => 'Allow User to Sort Results?',
+    'search_show_limit' => 'Show Page Limits?',
+    'search_separator' => 'Group Separator',
+    'search_def_keytype' => 'Default Search Method',
+    'search_def_sort' => 'Default Sort Order'
 );
 
 $LANG_configsubgroups['Core'] = array(
@@ -1847,7 +1980,17 @@ $LANG_configselects['Core'] = array(
     14 => array('Sunday' => 'Sun', 'Monday' => 'Mon'),
     15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
     16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
-    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1)
+    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
+    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
+    19 => array('Google' => 'google', 'Table' => 'table'),
+    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
+    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
+    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
+    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
+    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
+    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
+    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
+    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
 );
 
-?>
\ No newline at end of file
+?>
