@@ -45,10 +45,10 @@ $LANG01 = array(
     2 => 'czytaj dalej',
     3 => 'komentarzy',
     4 => 'Edycja',
-    5 => 'Gosuj',
-    6 => 'Wyniki',
+    5 => '',
+    6 => '',
     7 => '',
-    8 => 'gosw',
+    8 => '',
     9 => 'Menu Admina:',
     10 => 'Panel Sterowania',
     11 => 'Artykuy',
@@ -80,7 +80,7 @@ $LANG01 = array(
     37 => 'Brak artykuw uytkownika',
     38 => 'Syndykacja Treci',
     39 => 'Odwie',
-    40 => 'Masz <tt>register_globals = Off</tt> w pliku <tt>php.ini</tt>. Niestety, Geeklog wymaga <tt>register_globals</tt> aby byy ustawione na <strong>on</strong>. Prosz zmienie ustawienia na <strong>on</strong> i restartowa serwer www.',
+    40 => '',
     41 => 'Go',
     42 => 'Autor:',
     43 => 'Odpowiedz',
@@ -151,7 +151,7 @@ $LANG01 = array(
     108 => 'Oprnij Cache',
     109 => 'Zgo naduycie',
     110 => 'Powiadom administratora o tym wpisie',
-    111 => 'Wersja PDF',
+    111 => '',
     112 => 'Zarejestrowani Uytkownicy',
     113 => 'Dokumentacja',
     114 => 'POWIADOMIENIA ZWROTNE',
@@ -203,7 +203,24 @@ $LANG03 = array(
     24 => 'Gall Anonim',
     25 => 'Czy chcesz zgosi administratorowi ten komentarz?',
     26 => '%s zgosi nastpujcy komentarz:',
-    27 => 'Raport naduy'
+    27 => 'Raport naduy',
+    28 => 'Preview Changes',
+    29 => 'Submit Changes',
+    30 => 'Edited on',
+    31 => 'by',
+    32 => 'Editing a Comment',
+    33 => 'Editing a Comment Submission',
+    34 => 'Preview Submission Changes',
+    35 => 'Save Changes to Queue',
+    36 => 'Notify me of new replies',
+    37 => 'New Comment Reply',
+    38 => 'A reply has been made to your comment \'%s\'.',
+    39 => 'You may view the comment thread at the following address:',
+    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
+    41 => 'Hello %s,',
+    42 => 'Unsubscribe',
+    43 => 'Unsubscribe from reply notifications',
+    44 => 'Your Name'
 );
 
 ###############################################################################
@@ -349,7 +366,7 @@ $LANG04 = array(
     137 => 'Filtruj Zawarto Artykuw',
     138 => 'Ustawienia Rne',
     139 => 'Layout i Jzyk',
-    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics<li>Set the maximum number of stories to show per page</li><li>Set your theme and perferred date format</li>',
+    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
     141 => 'Ustawienia Prywatnoci',
     142 => 'The default setting is to allow users & admins to email fellow site members and show your status as online. Un-check these options to protect your privacy.',
     143 => 'Filtruj Zawarto Blokw',
@@ -363,7 +380,13 @@ $LANG04 = array(
     156 => 'Usu Konto',
     157 => 'Delete Option',
     158 => 'Strefa Czasowa',
-    159 => 'Ta wiadomo zostaa wygenerowana automatycznie. Prosz nie odpowiada.'
+    159 => 'Ta wiadomo zostaa wygenerowana automatycznie. Prosz nie odpowiada.',
+    160 => '(max. %d x %d pixels, %d bytes; %s)',
+    161 => 'will be scaled down',
+    162 => 'will not be scaled',
+    163 => 'Re-Authentication Failed',
+    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
+    165 => 'Use Advanced Editor'
 );
 
 ###############################################################################
@@ -431,7 +454,10 @@ $LANG08 = array(
     32 => 'Data',
     33 => 'Cay artyku dostpny tutaj ',
     34 => 'Koniec Wiadomoci',
-    35 => 'Sorry, ale ten uytkownik nie yczy sobie otrzymywania adnych emaili.'
+    35 => 'Sorry, ale ten uytkownik nie yczy sobie otrzymywania adnych emaili.',
+    36 => 'Copy:',
+    37 => 'Send me a copy of this email',
+    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
 );
 
 ###############################################################################
@@ -498,7 +524,18 @@ $LANG09 = array(
     58 => 'WIcej wynikw &gt;&gt;',
     59 => 'Wyniki',
     60 => 'na stron',
-    61 => 'Zmie zapytanie'
+    61 => 'Zmie zapytanie',
+    62 => '#',
+    63 => 'Description',
+    64 => 'Showing %1$d - %2$d of %3$d results',
+    65 => 'Story',
+    66 => 'Comment',
+    67 => 'Show %d Results',
+    68 => 'Sort By',
+    69 => 'Titles Only',
+    70 => 'Not available ...',
+    71 => 'asc',
+    72 => 'desc'
 );
 
 ###############################################################################
@@ -546,7 +583,7 @@ $LANG11 = array(
     2 => 'Wylij Znajomemu',
     3 => 'Wersja Do Wydruku',
     4 => 'Opcje Artykuu',
-    5 => 'Format PDF',
+    5 => '',
     6 => 'Subscribe to \'%s\''
 );
 
@@ -681,7 +718,7 @@ $LANG21 = array(
     47 => '',
     48 => 'Nazwa Bloku',
     49 => ' (nazwa unikalna i bez spacji)',
-    50 => '',
+    50 => 'The Block Name can not be empty',
     51 => 'uwzgldnij http://',
     52 => 'Jeli zostawisz puste, ikona pomocy dla tego bloku si nie pojawi',
     53 => 'Aktywne',
@@ -768,7 +805,7 @@ $LANG24 = array(
     60 => '',
     61 => 'Auto Archiwizacja',
     62 => 'Auto Kasacja',
-    63 => '',
+    63 => 'Disable Comments',
     64 => '',
     65 => '',
     66 => '',
@@ -793,7 +830,10 @@ $LANG24 = array(
     85 => 'Poka Wszystko',
     86 => 'Edytor Zaawansowany',
     87 => 'Artyku - Statystyki',
-    88 => 'Format w stylu Wiki'
+    88 => 'Format w stylu Wiki',
+    89 => 'Meta Description',
+    90 => 'Meta Keywords',
+    91 => 'You can always hit "Preview" to extend the expiry time.'
 );
 
 ###############################################################################
@@ -828,7 +868,8 @@ $LANG27 = array(
     26 => 'domylna sekcja dla archiwizowanych artykuw. Dozwolona jest tylko jedna sekcja.',
     27 => 'Lub Wgraj Ikon Sekcji',
     28 => 'Max',
-    29 => 'Bd podczas przesyania pliku'
+    29 => 'Bd podczas przesyania pliku',
+    30 => 'Stories in Topic'
 );
 
 ###############################################################################
@@ -919,7 +960,12 @@ $LANG28 = array(
     82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
     83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
     84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
-    85 => 'If you have forgotten the password use the following link: %s'
+    85 => 'If you have forgotten the password use the following link: %s',
+    86 => 'Include',
+    87 => 'Reminders',
+    88 => 'Default Group',
+    89 => 'Check to make this a default group for new users',
+    90 => 'Apply "Default Group" change to existing user accounts'
 );
 
 ###############################################################################
@@ -941,11 +987,14 @@ $LANG29 = array(
     18 => 'Email',
     34 => 'Panel Sterowania',
     35 => 'Przesane Artykuy',
-    36 => '',
+    36 => 'Parent or Comment',
     37 => '',
     38 => 'Przelij',
     39 => 'adnych materiaw do zatwierdzenia',
-    40 => 'Materiay przesane przez uytkownika'
+    40 => 'Materiay przesane przez uytkownika',
+    41 => 'Comment Submissions',
+    42 => 'Username',
+    43 => 'Auto-publish Comments?'
 );
 
 ###############################################################################
@@ -1021,7 +1070,21 @@ $LANG32 = array(
     35 => 'Edit',
     36 => 'Code',
     37 => 'Data',
-    38 => 'Update!'
+    38 => 'Update!',
+    39 => 'Upload a plugin',
+    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
+    41 => 'Upload',
+    42 => 'Click to update',
+    99 => 'An unknown error occured',
+    100 => 'Ok.',
+    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
+    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
+    103 => 'The uploaded file was only partially uploaded.',
+    104 => 'No file was uploaded.',
+    105 => '(undefined error)',
+    106 => 'Missing a temporary folder.',
+    107 => 'Failed to write file to disk.',
+    108 => 'File upload stopped by extension.'
 );
 
 ###############################################################################
@@ -1098,8 +1161,8 @@ $MESSAGE = array(
     12 => 'Blok zosta wykasowany.',
     13 => 'Sekcja zostaa zapisana.',
     14 => 'Sekcja oraz wszystkie artykuy i bloki z ni zwizane zostay wykasowane.',
-    15 => '',
-    16 => '',
+    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
+    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
     17 => '',
     18 => '',
     19 => '',
@@ -1112,25 +1175,25 @@ $MESSAGE = array(
     26 => '',
     27 => 'Wiadomo wysano.',
     28 => 'Plugin zosta zapisany',
-    29 => '',
+    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
     30 => 'Odmowa Dostpu',
-    31 => 'Sorry, nie masz dostpu do strony administrujcej artykuami.  Wszelkie nieautoryzowane prby wejcia s logowane',
-    32 => 'Sorry, nie masz dostpu do strony administrujcej sekcjami.  Wszelkie nieautoryzowane prby wejcia s logowane',
-    33 => 'Sorry, nie masz dostpu do strony administrujcej blokami.  Wszelkie nieautoryzowane prby wejcia s logowane',
+    31 => '',
+    32 => '',
+    33 => '',
     34 => '',
     35 => '',
     36 => '',
-    37 => 'Sorry, nie masz dostpu do strony administrujcej uytkownikami.  Wszelkie nieautoryzowane prby wejcia s logowane',
-    38 => 'Sorry, nie masz dostpu do strony administrujcej pluginami.  Wszelkie nieautoryzowane prby wejcia s logowane',
-    39 => 'Sorry, nie masz dostpu do strony administrujcej mailem.  Wszelkie nieautoryzowane prby wejcia s logowane',
+    37 => '',
+    38 => '',
+    39 => '',
     40 => 'Komunikat Systemowy',
-    41 => 'Sorry, nie masz dostpu do strony edycyjnej zamiennikw sw.  Wszelkie nieautoryzowane prby wejcia s logowane',
-    42 => 'Sowo zostao zapisane.',
-    43 => 'Sowo zostao wykasowane.',
+    41 => '',
+    42 => '',
+    43 => '',
     44 => 'Plugin zosta zainstalowany!',
     45 => 'Plugin zosta wykasowany.',
-    46 => 'Sorry, nie masz dostpu do opcji archiwizowania bazy danych.  Pamitaj, e Wszelkie nieautoryzowane prby wejcia s logowane',
-    47 => 'Ta opcja dziaa tylko pod systemem *nixowym. Jeli masz wanie taki system operacyjny to cache zosta wyczyszczony. Pod Windoz, musisz poszuka plikw adodb_*.php i usun je rcznie.',
+    46 => '',
+    47 => '',
     48 => "Dziekujemy za zainteresowanie czonkowstwem w {$_CONF['site_name']}. Zweryfikujemy twoje zgoszenie i po zatwierdzeniu zostanie wysane haso pod podany adres e-mail.",
     49 => 'Twoja grupa zostaa zapisana.',
     50 => 'Grupa zostaa wykasowana.',
@@ -1179,8 +1242,14 @@ $MESSAGE = array(
     93 => 'Database back up was successful.',
     94 => 'Backup Failed: Filesize less than 1kb',
     95 => 'There was an error.',
-    96 => 'Sorry, you do not have access to the configuration administration page.  Please note that all attempts to access unauthorized features are logged.',
-    97 => 'Not all required fields have been passed validation - default custom membership message'
+    96 => '',
+    97 => '',
+    98 => 'The plugin was successfully uploaded.',
+    99 => 'The plugin already exists.',
+    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
+    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
+    400 => 'Not all required fields have been passed validation',
+    401 => 'Please enter Fullname'
 );
 
 ###############################################################################
@@ -1267,7 +1336,26 @@ $LANG_DB_BACKUP = array(
     'size' => 'Rozmiar',
     'bytes' => 'Bajtw',
     'total_number' => 'Wszystkich kopii bezpieczestwa: %d',
-    'download' => 'Click to download this file'
+    'download' => 'Click to download this file',
+    'new_backup' => 'New Backup',
+    'delete_failure' => 'One or more backup files could not be deleted.',
+    'delete_success' => 'Backup file(s) successfully deleted.',
+    'convert_menu' => 'Convert to InnoDB',
+    'convert_title' => 'Convert to InnoDB tables',
+    'convert_button' => 'Convert',
+    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
+    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
+    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
+    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
+    'innodb_success' => 'Successfully converted tables to InnoDB.',
+    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
+    'optimize_menu' => 'Optimize Tables',
+    'optimize_title' => 'Optimize Tables',
+    'optimize_button' => 'Optimize',
+    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
+    'last_optimization' => 'Last optimization',
+    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
+    'optimize_success' => 'Successfully optimized database tables.'
 );
 
 ###############################################################################
@@ -1305,26 +1393,6 @@ $LANG_LOGIN = array(
     4 => 'Nowy Uytkownik'
 );
 
-###############################################################################
-# pdfgenerator.php
-
-$LANG_PDF = array(
-    1 => 'Opcja PDF zostaa wyczona',
-    2 => 'Dany dokument nie zosta wygenerowany. Dokument zosta otrzymany ale nie mg by przetworzony.  Upewnij si, e przesane dokumenty html zostay zapisane w standardowym xHTML. Prosz mie na uwadze, e skomplikowane dokumenty html-owe mog zosta przetworzone z bdem lub w ogle. Dokument, ktry prbowaa/e wygenrowa mia rozmiar 0 bajtw i zosta usunity. Jeli uwaasz, e Twj dokument powinien zosta wygenerowany prawidowo, przelij go raz jeszcze.',
-    3 => 'Nieznany bd podczas generowania pliku PDF',
-    4 => "Nie okrelono adnej strony albo chcesz uy poniszego narzdzia do generowania PDF-a ad-hoc.  Jeli uwaasz, e strona to bd\n          skontaktuj si z administratorem systemu.  W przeciwnym razie, uyj poniszego formularza aby wygenerowa PDF-a metod ad-hoc.",
-    5 => 'adowanie dokumentu.',
-    6 => 'Prosz poczeka na zaadowanie dokumentu.',
-    7 => 'Kliknij prawym przyciskiem myszy i wybierz \'zapisz element docelowy jako...\' lub \'zapisz link...\' aby zachowa kopi dokumentu na Twoim komputerze.',
-    8 => "The path given in the configuration file to the HTMLDoc binary is invalid or this system cannot execute it.  Please contact the site administrator if this problem\n          persists.",
-    9 => 'Generator PDF',
-    10 => "This is the Ad-hoc PDF Generation tool. It will attempt to convert any URL you give into a PDF.  Please note that some web pages will not render properly with this feature.  This\n           is a limitation of the HTMLDoc PDF generation tool and such errors should not be reported to the administrators of this site",
-    11 => 'URL',
-    12 => 'Generuj PDF!',
-    13 => 'Konfiguracja PHP na tym serwerze nie pozwala na uycie URL z komend fopen().  Administrator systemu musi edytowa plik php.ini i ustawi allow_url_fopen na On',
-    14 => 'dany PDF albo nie istnieje albo nie masz do niego uprawnie.'
-);
-
 ###############################################################################
 # trackback.php
 
@@ -1423,6 +1491,31 @@ $LANG_DIR = array(
     'no_articles' => 'No articles.'
 );
 
+###############################################################################
+# admin/sectest.php
+
+$LANG_SECTEST = array(
+    'sectest' => 'Geeklog Security Check',
+    'results' => 'Results of the Security Check',
+    'okay' => 'Everything seems to be in order.',
+    'please_fix' => 'Please fix the above issues before using your site!',
+    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
+    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
+    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
+    'installation' => 'installation instructions',
+    'directory' => 'directory',
+    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
+    'fix_it' => 'This is a security risk and should be fixed!',
+    'reachable' => 'Your %s is reachable from the web.',
+    'not_reachable' => 'Good! Your %s is not reachable from the web.',
+    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
+    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
+    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
+    'inst_removed' => 'Good! You seem to have removed the install directory already.',
+    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
+    'password_okay' => 'Good! You seem to have changed the default account password already.'
+);
+
 ###############################################################################
 # "What's New" Time Strings
 # 
@@ -1496,6 +1589,7 @@ $LANG_ADMIN = array(
     'create_new_adv' => 'Create New (Adv.)',
     'enabled' => 'Enabled',
     'title' => 'Title',
+    'page_title' => 'Page Title',
     'type' => 'Type',
     'topic' => 'Topic',
     'help_url' => 'Help File URL',
@@ -1510,7 +1604,14 @@ $LANG_ADMIN = array(
     'records_found' => 'Records found',
     'addchild' => 'Add child',
     'list' => 'list',
-    'list_all' => 'List all'
+    'list_all' => 'List all',
+    'meta_description' => 'Meta Description',
+    'meta_keywords' => 'Meta Keywords',
+    'na' => 'N/A',
+    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
+    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
+    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
+    'authenticate' => 'Authenticate'
 );
 
 # Localisation of the texts for the various drop-down menus that are actually
@@ -1583,7 +1684,8 @@ $LANG_CONFIG = array(
     'reset_form' => 'Resetuj zmiany',
     'changes_made' => 'Changes were successfully made to',
     'title' => 'Menader ustawie',
-    'disable' => 'Kliknij aby wyczy t opcj'
+    'disable' => 'Kliknij aby wyczy t opcj',
+    'enable' => 'Enable'
 );
 
 $LANG_configsections['Core'] = array(
@@ -1611,7 +1713,9 @@ $LANG_confignames['Core'] = array(
     'allow_mysqldump' => 'Zezwalaj na zrzut MySQL',
     'mysqldump_path' => 'cieka do plikw wykonawczych',
     'mysqldump_options' => 'Opcje zrzutu MySQL',
+    'mysqldump_filename_mask' => 'Backup File Name Mask',
     'theme' => 'Layout',
+    'doctype' => 'DOCTYPE Declaration',
     'menu_elements' => 'Elementy Menu',
     'path_themes' => 'cieka do katalogu z layoutami',
     'disable_new_user_registration' => 'Wycz rejestracj nowych uytkownikw',
@@ -1650,6 +1754,7 @@ $LANG_confignames['Core'] = array(
     'cookie_theme' => 'Nazwa ciasteczka layoutu',
     'cookie_language' => 'Nazwa ciasteczka jzykowego',
     'cookie_tzid' => 'Nazwa ciasteczka strefy czasowej',
+    'cookie_anon_name' => 'Anon. Username Cookie Name',
     'cookie_ip' => 'Czy ciasteczko ma zawiera adres IP?',
     'default_perm_cookie_timeout' => 'Stae wyganicie',
     'session_cookie_timeout' => 'Wyganicie sesji',
@@ -1657,7 +1762,6 @@ $LANG_confignames['Core'] = array(
     'cookiedomain' => 'Domena ciasteczek',
     'cookiesecure' => 'Cookie Secure',
     'lastlogin' => 'Zarejestrowa ostatnie logowanie?',
-    'pdf_enabled' => 'PDF wczony?',
     'num_search_results' => 'Liczba wynikw z wyszukiwarki',
     'loginrequired' => 'Wymagane zalogowanie?',
     'submitloginrequired' => 'Wymagane zalogowanie do przesania materiaw?',
@@ -1741,6 +1845,7 @@ $LANG_confignames['Core'] = array(
     'debug_image_upload' => 'Debug Image Uploading?',
     'keep_unscaled_image' => 'Keep Unscaled Image?',
     'allow_user_scaling' => 'Allow User Scaling?',
+    'jpeg_quality' => 'JPEG Quality?',
     'max_image_width' => 'Max Image Width?',
     'max_image_height' => 'Max Image Height?',
     'max_image_size' => 'Max Image Size?',
@@ -1751,32 +1856,55 @@ $LANG_confignames['Core'] = array(
     'max_photo_height' => 'Max Photo Height?',
     'max_photo_size' => 'Max Photo Size?',
     'use_gravatar' => 'Use Gravatar?',
-    'gravatar_rating' => 'Gravatar Rating Allowed',
+    'gravatar_rating' => 'Gravatar Rating',
     'force_photo_width' => 'Force Photo Width',
     'default_photo' => 'Default Photo',
     'commentspeedlimit' => 'Comment Speed Limit',
     'comment_limit' => 'Comment Limit',
     'comment_mode' => 'Comment Mode',
     'comment_code' => 'Comment Default',
+    'comment_edit' => 'Allow Comment Edit?',
+    'comment_edittime' => 'Comment Edit Time (seconds)',
+    'commentsubmission' => 'Queue Comment Submissions',
     'passwordspeedlimit' => 'Password Speed Limit',
     'login_attempts' => 'Max. Login Attempts',
     'login_speedlimit' => 'Login Speed Limit',
     'user_html' => 'User HTML',
     'admin_html' => 'Admin HTML',
+    'advanced_html' => 'Additional HTML for Adv. Editor',
     'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
     'allowed_protocols' => 'Allowed Protocols',
-    'disable_autolinks' => 'Disable Autolinks?',
+    'disable_autolinks' => 'Disable Autotags?',
+    'clickable_links' => 'Make URLs clickable?',
+    'compressed_output' => 'Send compressed output?',
+    'frame_options' => 'Protection against "clickjacking"',
     'censormode' => 'Censor Mode?',
     'censorreplace' => 'Censor Replace Text',
     'censorlist' => 'Censor List',
     'ip_lookup' => 'IP Lookup',
     'url_rewrite' => 'Wcz przyjazne adresy URL',
+    'meta_tags' => 'Meta Tags',
+    'meta_description' => 'Default Meta Description',
+    'meta_keywords' => 'Default Meta Keywords',
     'default_permissions_block' => 'Block Default Permissions',
     'default_permissions_story' => 'Story Default Permissions',
     'default_permissions_topic' => 'Topic Default Permissions',
     'atom_max_stories' => 'Max. Stories in Webservices Feed',
     'disable_webservices' => 'Disable Webservices?',
-    'restrict_webservices' => 'Restrict Webservices?'
+    'restrict_webservices' => 'Restrict Webservices?',
+    'article_comment_close_enabled' => 'Automatically close comments (default)',
+    'article_comment_close_days' => 'Days to close comments (default)',
+    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
+    'allow_reply_notifications' => 'Allow comment reply notifications?',
+    'search_style' => 'Results List Style',
+    'search_limits' => 'Page Limits',
+    'search_show_num' => 'Show Result Number?',
+    'search_show_type' => 'Show Result Type?',
+    'search_show_sort' => 'Allow User to Sort Results?',
+    'search_show_limit' => 'Show Page Limits?',
+    'search_separator' => 'Group Separator',
+    'search_def_keytype' => 'Default Search Method',
+    'search_def_sort' => 'Default Sort Order'
 );
 
 $LANG_configsubgroups['Core'] = array(
@@ -1853,7 +1981,16 @@ $LANG_configselects['Core'] = array(
     15 => array('Liczbowo' => 'sortnum', 'Alfabetycznie' => 'alpha'),
     16 => array('Login nie wymagany' => 0, 'Tylko wyszukiwanie zaawansowane' => 1, 'Wyszukiwanie proste + zaawansowane' => 2),
     17 => array('Komentarze wczone' => 0, 'Komentarze wyczone' => -1),
-    18 => array('Wyczone' => 0, 'Wczone (Dokadne trafienie)' => 1, 'Wczone (Pocztek sowa)' => 2, 'Wczone (Fragment sowa)' => 3)
+    18 => array('Wyczone' => 0, 'Wczone (Dokadne trafienie)' => 1, 'Wczone (Pocztek sowa)' => 2, 'Wczone (Fragment sowa)' => 3),
+    19 => array('Google' => 'google', 'Table' => 'table'),
+    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
+    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
+    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
+    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
+    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
+    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
+    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
+    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
 );
 
 ?>
