@@ -45,10 +45,10 @@ $LANG01 = array(
     2 => 'devamý',
     3 => 'yorum',
     4 => 'Deðiþtir',
-    5 => 'Oy Kullan',
-    6 => 'Sonuçlar',
+    5 => '',
+    6 => '',
     7 => '',
-    8 => 'oy',
+    8 => '',
     9 => 'Yönetici kontrolleri:',
     10 => 'Gönderilenler',
     11 => 'Yazýlar',
@@ -80,7 +80,7 @@ $LANG01 = array(
     37 => 'Kullanýcýlardan hiç bir yazý gelmemiþ',
     38 => 'Content Syndication',
     39 => 'Yenile',
-    40 => 'php.ini parametlerinizden <tt>register_globals = Off</tt> konumundadýr. ancak, Geeklog  için <tt>register_globals</tt>parametresinin <strong>on</strong> konumunda olmasý gerekmektedir. Before you continue, please set it to <strong>on</strong> and restart your web server.Lütfen servis saðlayýcýnýz ile kontakt kurunuz',
+    40 => '',
     41 => 'Misafirler',
     42 => 'Yazar:',
     43 => 'Cevap Ver',
@@ -135,7 +135,7 @@ $LANG01 = array(
     92 => 'saniye',
     93 => 'Copyright',
     94 => 'Bu sayfalarda yayýmlanan materyalin tüm haklarý sahiplerine aittir.',
-    95 => 'Powered By:',
+    95 => 'Powered by:',
     96 => 'Gruplar',
     97 => 'Kelime Listesi',
     98 => 'Eklentiler',
@@ -151,7 +151,7 @@ $LANG01 = array(
     108 => 'Önbelleði Temizle',
     109 => 'Uygunsuz içerik',
     110 => 'Bu iletiyi site adminine bildirin',
-    111 => 'PDF Versiyonu göster',
+    111 => '',
     112 => 'Kayýtlý Üyeler',
     113 => 'Dökümantasyon',
     114 => 'TRACKBACKS',
@@ -203,7 +203,24 @@ $LANG03 = array(
     24 => 'Herhangi Kullanýcý',
     25 => 'Bu iletiyi site adminine bildirmek istediðinize emin misiniz?',
     26 => '%s Bu ileti site adminine bildirilmiþtir:',
-    27 => 'Þikayet Et'
+    27 => 'Þikayet Et',
+    28 => 'Preview Changes',
+    29 => 'Submit Changes',
+    30 => 'Edited on',
+    31 => 'by',
+    32 => 'Editing a Comment',
+    33 => 'Editing a Comment Submission',
+    34 => 'Preview Submission Changes',
+    35 => 'Save Changes to Queue',
+    36 => 'Notify me of new replies',
+    37 => 'New Comment Reply',
+    38 => 'A reply has been made to your comment \'%s\'.',
+    39 => 'You may view the comment thread at the following address:',
+    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
+    41 => 'Hello %s,',
+    42 => 'Unsubscribe',
+    43 => 'Unsubscribe from reply notifications',
+    44 => 'Your Name'
 );
 
 ###############################################################################
@@ -349,7 +366,7 @@ $LANG04 = array(
     137 => 'Yazý Ýçeriði Filtreleme',
     138 => 'Diðer Ayarlar',
     139 => 'Görünüm ve Language',
-    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics<li>Set the maximum number of stories to show per page</li><li>Set your theme and perferred date format</li>',
+    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
     141 => 'Eriþilebilirlik Ayarlarý',
     142 => 'Geçerli site ayarlarý üyelerden ve yöneticiden üye almanýza izin vermekte ve online kullanýlar bloðunda görünmenize izin vermektedir.Kutuda iþareti kaldýrarak istemediðiniz özelliði iptal edebilirsiniz.',
     143 => 'Block Ýçeriði Filtresi',
@@ -363,7 +380,13 @@ $LANG04 = array(
     156 => 'Hesabýmý Sil',
     157 => 'Delete Option',
     158 => 'Time Zone',
-    159 => 'This email was generated automatically. Please do not reply to this email.'
+    159 => 'This email was generated automatically. Please do not reply to this email.',
+    160 => '(max. %d x %d pixels, %d bytes; %s)',
+    161 => 'will be scaled down',
+    162 => 'will not be scaled',
+    163 => 'Re-Authentication Failed',
+    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
+    165 => 'Use Advanced Editor'
 );
 
 ###############################################################################
@@ -431,7 +454,10 @@ $LANG08 = array(
     32 => 'Tarih',
     33 => 'Yazýnýn tamamý için:',
     34 => 'Mesajýn Sonu',
-    35 => 'Üzgünüz, bu kullanýcý hiç mail almamayý tercih etmiþ.'
+    35 => 'Üzgünüz, bu kullanýcý hiç mail almamayý tercih etmiþ.',
+    36 => 'Copy:',
+    37 => 'Send me a copy of this email',
+    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
 );
 
 ###############################################################################
@@ -498,7 +524,18 @@ $LANG09 = array(
     58 => 'Daha fazla sonuç &gt;&gt;',
     59 => 'Sonuçlar',
     60 => 'sayfa',
-    61 => 'Basit Arama'
+    61 => 'Basit Arama',
+    62 => '#',
+    63 => 'Description',
+    64 => 'Showing %1$d - %2$d of %3$d results',
+    65 => 'Story',
+    66 => 'Comment',
+    67 => 'Show %d Results',
+    68 => 'Sort By',
+    69 => 'Titles Only',
+    70 => 'Not available ...',
+    71 => 'asc',
+    72 => 'desc'
 );
 
 ###############################################################################
@@ -546,7 +583,7 @@ $LANG11 = array(
     2 => 'Arkadaþýna Gönder',
     3 => 'Basýlmaya Uygun Þekli',
     4 => 'Seçenekler',
-    5 => 'PDF Yazý Formatý',
+    5 => '',
     6 => 'Subscribe to \'%s\''
 );
 
@@ -681,7 +718,7 @@ $LANG21 = array(
     47 => '',
     48 => 'Alan Adý',
     49 => ' (boþluk kullanýlmamalý ve tek olmalý)',
-    50 => '',
+    50 => 'The Block Name can not be empty',
     51 => 'http:// ile baþlayýn',
     52 => 'Bu alaný boþ býrakýrsanýz, blok ile iliþkili yardým düðmesi gösterilmeyecektir',
     53 => 'Kullanýma Açýk',
@@ -768,7 +805,7 @@ $LANG24 = array(
     60 => '',
     61 => 'Auto Archive',
     62 => 'Otomatik Silme',
-    63 => '',
+    63 => 'Disable Comments',
     64 => '',
     65 => '',
     66 => '',
@@ -793,7 +830,10 @@ $LANG24 = array(
     85 => 'Tümünü Göster',
     86 => 'Geliþmiþ Editor',
     87 => 'Yazý Ýstatistikleri',
-    88 => 'Wiki-style format'
+    88 => 'Wiki-style format',
+    89 => 'Meta Description',
+    90 => 'Meta Keywords',
+    91 => 'You can always hit "Preview" to extend the expiry time.'
 );
 
 ###############################################################################
@@ -828,7 +868,8 @@ $LANG27 = array(
     26 => 'Arþivlenmiþ yazýlar için geçerli baþlýk yap.Sadece bir konu izinli.',
     27 => 'Veya Konu Simgesi Upload Et',
     28 => 'EN Fazla',
-    29 => 'Dosya Upload Hatalarý'
+    29 => 'Dosya Upload Hatalarý',
+    30 => 'Stories in Topic'
 );
 
 ###############################################################################
@@ -919,7 +960,12 @@ $LANG28 = array(
     82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
     83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
     84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
-    85 => 'If you have forgotten the password use the following link: %s'
+    85 => 'If you have forgotten the password use the following link: %s',
+    86 => 'Include',
+    87 => 'Reminders',
+    88 => 'Default Group',
+    89 => 'Check to make this a default group for new users',
+    90 => 'Apply "Default Group" change to existing user accounts'
 );
 
 ###############################################################################
@@ -941,11 +987,14 @@ $LANG29 = array(
     18 => 'Email',
     34 => 'Kontrol',
     35 => 'Eklenen Yazýlar',
-    36 => '',
+    36 => 'Parent or Comment',
     37 => '',
     38 => 'Gönder',
     39 => 'Onaylamanýz gereken herhangi bir eklenti yok',
-    40 => 'Kullanýcýlarýn ekledikleri'
+    40 => 'Kullanýcýlarýn ekledikleri',
+    41 => 'Comment Submissions',
+    42 => 'Username',
+    43 => 'Auto-publish Comments?'
 );
 
 ###############################################################################
@@ -1021,7 +1070,21 @@ $LANG32 = array(
     35 => 'Düzenle',
     36 => 'Code',
     37 => 'Data',
-    38 => 'Güncelle!'
+    38 => 'Güncelle!',
+    39 => 'Upload a plugin',
+    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
+    41 => 'Upload',
+    42 => 'Click to update',
+    99 => 'An unknown error occured',
+    100 => 'Ok.',
+    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
+    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
+    103 => 'The uploaded file was only partially uploaded.',
+    104 => 'No file was uploaded.',
+    105 => '(undefined error)',
+    106 => 'Missing a temporary folder.',
+    107 => 'Failed to write file to disk.',
+    108 => 'File upload stopped by extension.'
 );
 
 ###############################################################################
@@ -1098,8 +1161,8 @@ $MESSAGE = array(
     12 => 'Bloðunuz baþarýyla silindi.',
     13 => 'Konunuz baþarýyla kaydedildi.',
     14 => 'Konunuz ve bütün yazýlarý ve alanlarý baþarýyla silindi.',
-    15 => '',
-    16 => '',
+    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
+    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
     17 => '',
     18 => '',
     19 => '',
@@ -1112,25 +1175,25 @@ $MESSAGE = array(
     26 => '',
     27 => 'Mesaj baþarýlya iletildi.',
     28 => 'Eklenti baþarýyla eklendi.',
-    29 => '',
+    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
     30 => 'Eriþim Engellendi',
-    31 => 'Yazý kontrol sayfalarýna eriþiminiz yok.  Giriþ izni olmayan tüm etkinlikler kayýtlara geçmektedir.',
-    32 => 'Konu kontrol sayfalarýna eriþiminiz yok.  Giriþ izni olmayan tüm etkinlikler kayýtlara geçmektedir.',
-    33 => 'Blok kontrol sayfalarýna eriþiminiz yok.  Giriþ izni olmayan tüm etkinlikler kayýtlara geçmektedir.',
+    31 => '',
+    32 => '',
+    33 => '',
     34 => '',
     35 => '',
     36 => '',
-    37 => 'Kullanýcý kontrol sayfalarýna eriþiminiz yok.  Giriþ izni olmayan tüm etkinlikler kayýtlara geçmektedir.',
-    38 => 'Eklenti kontrol sayfalarýna eriþiminiz yok.  Giriþ izni olmayan tüm etkinlikler kayýtlara geçmektedir.',
-    39 => 'Mesaj kontrol sayfalarýna eriþiminiz yok.  Giriþ izni olmayan tüm etkinlikler kayýtlara geçmektedir.',
+    37 => '',
+    38 => '',
+    39 => '',
     40 => 'Sistem Mesajý',
-    41 => 'Kelime deðiþtirme sayfasýna eriþiminiz yok.  Giriþ izni olmayan tüm etkinlikler kayýtlara geçmektedir.',
-    42 => 'Kelimeniz baþarýyla kaydedildi.',
-    43 => 'Kelimeniz  baþarýyla silindi.',
+    41 => '',
+    42 => '',
+    43 => '',
     44 => 'Eklenti baþarýlya yüklendi!',
     45 => 'Eklenti baþarýyla silindi.',
-    46 => 'Veri tabaný yedekleme programýna eriþimiz yok.  Giriþ izni olmayan tüm etkinlikler kayýtlara geçmektedir.',
-    47 => 'Bu özellik sadece Linux, Unix gibi iþletim sistemlerinde çalýþýr.  Eðer Linux, Unix gibi bir iþletim sistemi kullanýyorsanýz, önbelleðiniz baþarýyla temizlenmiþtir. Eðer Windows kullanýyorsanýz, adodb_*.php  dosyalarýný aratýn ve silin.',
+    46 => '',
+    47 => '',
     48 => "{$_CONF['site_name']} sitesine üyelik baþvurunuz için teþekkür ederiz. Site yönetimi baþvurunuzu inceleyecektir. Eðer kabul alýrsanýz þifreniz belirttiðiniz eðmail adreisne gönderilecektir.",
     49 => 'Grubunuz baþarýyla kaydedildi.',
     50 => 'Grup baþarýyla silindi.',
@@ -1179,8 +1242,14 @@ $MESSAGE = array(
     93 => 'Database back up was successful.',
     94 => 'Backup Failed: Filesize less than 1kb',
     95 => 'There was an error.',
-    96 => 'Sorry, you do not have access to the configuration administration page.  Please note that all attempts to access unauthorized features are logged.',
-    97 => 'Not all required fields have been passed validation - default custom membership message'
+    96 => '',
+    97 => '',
+    98 => 'The plugin was successfully uploaded.',
+    99 => 'The plugin already exists.',
+    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
+    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
+    400 => 'Not all required fields have been passed validation',
+    401 => 'Please enter Fullname'
 );
 
 ###############################################################################
@@ -1267,7 +1336,26 @@ $LANG_DB_BACKUP = array(
     'size' => 'Boyut',
     'bytes' => 'Bayt',
     'total_number' => 'Toplam backup sayýsý: %d',
-    'download' => 'Click to download this file'
+    'download' => 'Click to download this file',
+    'new_backup' => 'New Backup',
+    'delete_failure' => 'One or more backup files could not be deleted.',
+    'delete_success' => 'Backup file(s) successfully deleted.',
+    'convert_menu' => 'Convert to InnoDB',
+    'convert_title' => 'Convert to InnoDB tables',
+    'convert_button' => 'Convert',
+    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
+    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
+    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
+    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
+    'innodb_success' => 'Successfully converted tables to InnoDB.',
+    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
+    'optimize_menu' => 'Optimize Tables',
+    'optimize_title' => 'Optimize Tables',
+    'optimize_button' => 'Optimize',
+    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
+    'last_optimization' => 'Last optimization',
+    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
+    'optimize_success' => 'Successfully optimized database tables.'
 );
 
 ###############################################################################
@@ -1305,26 +1393,6 @@ $LANG_LOGIN = array(
     4 => 'Yeni Kullanýcý'
 );
 
-###############################################################################
-# pdfgenerator.php
-
-$LANG_PDF = array(
-    1 => 'PDF özelliði kapatýldý',
-    2 => 'The document provided was not rendered. The document was received but could not be processed.  Please make sure to submit only html formatted documents that have been written to the xHTML standard. Please note that overly complex html documents may not render correctly or at all.The document resulting from your attempt was 0 bytes in length, and has been silindi. If you\'re sure that your document should render fine, please re-submit it.',
-    3 => 'Unknown error during PDF generation',
-    4 => "No page data was given or you want to use the ad-hoc PDF generation tool below.  If you think you are getting this page\n          in error then please contact the system administrator.  Otherwise, you may use the form below to generate PDF's in an ad-hoc fashion.",
-    5 => 'Yükleniyor .',
-    6 => 'Please wait while your document is loaded.',
-    7 => 'You may right click the button below and choose \'save target...\' or \'save link location...\' to save a copy of your document.',
-    8 => "The path given in the configuration file to the HTMLDoc binary is invalid or this system cannot execute it.  Please contact the site administrator if this problem\n          persists.",
-    9 => 'PDF Generator',
-    10 => "This is the Ad-hoc PDF Generation tool. It will attempt to convert any URL you give into a PDF.  Please note that some web pages will not render properly with this feature.  This\n           is a limitation of the HTMLDoc PDF generation tool and such errors should not be reported to the administrators of this site",
-    11 => 'URL',
-    12 => 'PDF Oluþtur!',
-    13 => 'The PHP configuration on this server does not allow URLs to be used with the fopen() command.  The system administrator must edit the php.ini file and set allow_url_fopen to On',
-    14 => 'The PDF you requested either does not exist or you tried to illegally access a file.'
-);
-
 ###############################################################################
 # trackback.php
 
@@ -1423,6 +1491,31 @@ $LANG_DIR = array(
     'no_articles' => 'Articles Yok.'
 );
 
+###############################################################################
+# admin/sectest.php
+
+$LANG_SECTEST = array(
+    'sectest' => 'Geeklog Security Check',
+    'results' => 'Results of the Security Check',
+    'okay' => 'Everything seems to be in order.',
+    'please_fix' => 'Please fix the above issues before using your site!',
+    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
+    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
+    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
+    'installation' => 'installation instructions',
+    'directory' => 'directory',
+    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
+    'fix_it' => 'This is a security risk and should be fixed!',
+    'reachable' => 'Your %s is reachable from the web.',
+    'not_reachable' => 'Good! Your %s is not reachable from the web.',
+    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
+    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
+    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
+    'inst_removed' => 'Good! You seem to have removed the install directory already.',
+    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
+    'password_okay' => 'Good! You seem to have changed the default account password already.'
+);
+
 ###############################################################################
 # "What's New" Time Strings
 # 
@@ -1496,6 +1589,7 @@ $LANG_ADMIN = array(
     'create_new_adv' => 'Yeni Oluþtur(Glþmþ.)',
     'enabled' => 'Ýzinli',
     'title' => 'Baþlýk',
+    'page_title' => 'Page Title',
     'type' => 'Tip',
     'topic' => 'Konu',
     'help_url' => 'Yardým Dosyasý URL',
@@ -1510,7 +1604,14 @@ $LANG_ADMIN = array(
     'records_found' => 'Kayýt Bulundu',
     'addchild' => 'Add child',
     'list' => 'list',
-    'list_all' => 'List all'
+    'list_all' => 'List all',
+    'meta_description' => 'Meta Description',
+    'meta_keywords' => 'Meta Keywords',
+    'na' => 'N/A',
+    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
+    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
+    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
+    'authenticate' => 'Authenticate'
 );
 
 # Localisation of the texts for the various drop-down menus that are actually
@@ -1583,7 +1684,8 @@ $LANG_CONFIG = array(
     'reset_form' => 'Reset Form',
     'changes_made' => 'Changes were successfully made to',
     'title' => 'Configuration Manager',
-    'disable' => 'Click to disable this option'
+    'disable' => 'Click to disable this option',
+    'enable' => 'Enable'
 );
 
 $LANG_configsections['Core'] = array(
@@ -1611,7 +1713,9 @@ $LANG_confignames['Core'] = array(
     'allow_mysqldump' => 'Allow MySQL Dump',
     'mysqldump_path' => 'Path of Executable',
     'mysqldump_options' => 'MySQL Dump Options',
+    'mysqldump_filename_mask' => 'Backup File Name Mask',
     'theme' => 'Theme',
+    'doctype' => 'DOCTYPE Declaration',
     'menu_elements' => 'Menu Elements',
     'path_themes' => 'Themes Path',
     'disable_new_user_registration' => 'Disable New Registrations',
@@ -1650,6 +1754,7 @@ $LANG_confignames['Core'] = array(
     'cookie_theme' => 'Theme Cookie Name',
     'cookie_language' => 'Language Cookie Name',
     'cookie_tzid' => 'Timezone Cookie Name',
+    'cookie_anon_name' => 'Anon. Username Cookie Name',
     'cookie_ip' => 'Cookies embed IP?',
     'default_perm_cookie_timeout' => 'Permanent Timeout',
     'session_cookie_timeout' => 'Session Timeout',
@@ -1657,7 +1762,6 @@ $LANG_confignames['Core'] = array(
     'cookiedomain' => 'Cookie Domain',
     'cookiesecure' => 'Cookie Secure',
     'lastlogin' => 'Record Last Login?',
-    'pdf_enabled' => 'PDF Enabled?',
     'num_search_results' => 'Number of Search Results',
     'loginrequired' => 'Login Required?',
     'submitloginrequired' => 'Submit Login Required?',
@@ -1741,6 +1845,7 @@ $LANG_confignames['Core'] = array(
     'debug_image_upload' => 'Debug Image Uploading?',
     'keep_unscaled_image' => 'Keep Unscaled Image?',
     'allow_user_scaling' => 'Allow User Scaling?',
+    'jpeg_quality' => 'JPEG Quality?',
     'max_image_width' => 'Max Image Width?',
     'max_image_height' => 'Max Image Height?',
     'max_image_size' => 'Max Image Size?',
@@ -1751,32 +1856,55 @@ $LANG_confignames['Core'] = array(
     'max_photo_height' => 'Max Photo Height?',
     'max_photo_size' => 'Max Photo Size?',
     'use_gravatar' => 'Use Gravatar?',
-    'gravatar_rating' => 'Gravatar Rating Allowed',
+    'gravatar_rating' => 'Gravatar Rating',
     'force_photo_width' => 'Force Photo Width',
     'default_photo' => 'Default Photo',
     'commentspeedlimit' => 'Comment Speed Limit',
     'comment_limit' => 'Comment Limit',
     'comment_mode' => 'Comment Mode',
     'comment_code' => 'Comment Default',
+    'comment_edit' => 'Allow Comment Edit?',
+    'comment_edittime' => 'Comment Edit Time (seconds)',
+    'commentsubmission' => 'Queue Comment Submissions',
     'passwordspeedlimit' => 'Password Speed Limit',
     'login_attempts' => 'Max. Login Attempts',
     'login_speedlimit' => 'Login Speed Limit',
     'user_html' => 'User HTML',
     'admin_html' => 'Admin HTML',
+    'advanced_html' => 'Additional HTML for Adv. Editor',
     'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
     'allowed_protocols' => 'Allowed Protocols',
-    'disable_autolinks' => 'Disable Autolinks?',
+    'disable_autolinks' => 'Disable Autotags?',
+    'clickable_links' => 'Make URLs clickable?',
+    'compressed_output' => 'Send compressed output?',
+    'frame_options' => 'Protection against "clickjacking"',
     'censormode' => 'Censor Mode?',
     'censorreplace' => 'Censor Replace Text',
     'censorlist' => 'Censor List',
     'ip_lookup' => 'IP Lookup',
     'url_rewrite' => 'Enable URL Rewrite',
+    'meta_tags' => 'Meta Tags',
+    'meta_description' => 'Default Meta Description',
+    'meta_keywords' => 'Default Meta Keywords',
     'default_permissions_block' => 'Block Default Permissions',
     'default_permissions_story' => 'Story Default Permissions',
     'default_permissions_topic' => 'Topic Default Permissions',
     'atom_max_stories' => 'Max. Stories in Webservices Feed',
     'disable_webservices' => 'Disable Webservices?',
-    'restrict_webservices' => 'Restrict Webservices?'
+    'restrict_webservices' => 'Restrict Webservices?',
+    'article_comment_close_enabled' => 'Automatically close comments (default)',
+    'article_comment_close_days' => 'Days to close comments (default)',
+    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
+    'allow_reply_notifications' => 'Allow comment reply notifications?',
+    'search_style' => 'Results List Style',
+    'search_limits' => 'Page Limits',
+    'search_show_num' => 'Show Result Number?',
+    'search_show_type' => 'Show Result Type?',
+    'search_show_sort' => 'Allow User to Sort Results?',
+    'search_show_limit' => 'Show Page Limits?',
+    'search_separator' => 'Group Separator',
+    'search_def_keytype' => 'Default Search Method',
+    'search_def_sort' => 'Default Sort Order'
 );
 
 $LANG_configsubgroups['Core'] = array(
@@ -1853,7 +1981,16 @@ $LANG_configselects['Core'] = array(
     15 => array('By Number' => 'sortnum', 'Alphabetically' => 'alpha'),
     16 => array('No Login required' => 0, 'Advanced Search only' => 1, 'Simple + Advanced Search' => 2),
     17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1),
-    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3)
+    18 => array('Disabled' => 0, 'Enabled (Exact Match)' => 1, 'Enabled (Word Beginning)' => 2, 'Enabled (Word Fragment)' => 3),
+    19 => array('Google' => 'google', 'Table' => 'table'),
+    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
+    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
+    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
+    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
+    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
+    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
+    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
+    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
 );
 
-?>
\ No newline at end of file
+?>
