@@ -52,7 +52,7 @@ $LANG_CAL_1 = array(
     8 => '個人カレンダにこのイベントを追加すると、「個人カレンダ」をユーザ管理メニューから選択することで見ることができます。',
     9 => '個人カレンダに追加',
     10 => '個人カレンダから削除',
-    11 => "このイベントを %sの個人カレンダに追加",
+    11 => 'このイベントを %sの個人カレンダに追加',
     12 => 'イベント',
     13 => '開始',
     14 => '終了',
@@ -81,7 +81,7 @@ $LANG_CAL_1 = array(
     37 => '種類',
     38 => 'イベントの種類を編集',
     39 => '場所',
-    40 => 'イベントを登録：',
+    40 => 'イベントを登録:',
     41 => '全体カレンダ',
     42 => '個人カレンダ',
     43 => 'リンク',
@@ -101,7 +101,6 @@ $_LANG_CAL_SEARCH = array(
     'date_time' => '日時',
     'location' => '場所',
     'description' => '詳細'
-
 );
 
 ###############################################################################
@@ -110,13 +109,13 @@ $_LANG_CAL_SEARCH = array(
 $LANG_CAL_2 = array(
     8 => '個人イベント登録',
     9 => '%s イベント',
-    10 => 'イベント：',
+    10 => 'イベント:',
     11 => '全体カレンダ',
     12 => '個人カレンダ',
-    25 => '戻る：',
+    25 => '戻る:',
     26 => '全日',
     27 => '週',
-    28 => '個人カレンダ：',
+    28 => '個人カレンダ:',
     29 => '全体カレンダ',
     30 => 'イベントを削除',
     31 => '追加',
@@ -131,7 +130,7 @@ $LANG_CAL_2 = array(
     40 => '週',
     41 => '月',
     42 => '全体イベント投稿',
-    43 => 'イベント投稿',
+    43 => 'イベント投稿'
 );
 
 ###############################################################################
@@ -165,7 +164,7 @@ $LANG_CAL_ADMIN = array(
     25 => '終了日時を正しく入力してください。',
     26 => '古いイベントの削除',
     27 => '以下のリストは ',
-    28 => ' ヶ月以上前のイベントです。 これらを削除する場合はゴミ箱アイコンをクリックしてください。または、異なる期間を選択してください：<br' . XHTML . '> ',
+    28 => ' ヶ月以上前のイベントです。 これらを削除する場合はゴミ箱アイコンをクリックしてください。または、異なる期間を選択してください:<br' . XHTML . '> ',
     29 => ' ヶ月以上前のイベントを検索します。',
     30 => 'リストの更新',
     31 => '選択したユーザを本当に削除してもよろしいですか?',
@@ -183,10 +182,10 @@ $LANG_CAL_MESSAGE = array(
     'login'     => '個人カレンダを開くには、最初にログインしてください。',
     'removed'   => '個人カレンダからイベントが削除されました。',
     'noprivate' => '申し訳ありませんが、このサイトでは、個人カレンダが無効です。',
-    'unauth'    => '申し訳ありませんが、イベント管理ページにアクセスする権限がありません。このアクセスは記録させていただきましたのでご了承ください。',
+    'unauth'    =>'申し訳ありませんが、イベント管理ページにアクセスする権限がありません。このアクセスは記録させていただきましたのでご了承ください。'
 );
 
-$PLG_calendar_MESSAGE4  = "{$_CONF['site_name']}にイベントを投稿していただき、ありがとうございます。スタッフに送信され、承認待ちの状態になりました。承認された場合、このサイトの<a href=\"{$_CONF['site_url']}/calendar/index.php\">カレンダ</a>セクションに表示されます。";
+$PLG_calendar_MESSAGE4 = "{$_CONF['site_name']}にイベントを投稿していただき、ありがとうございます。スタッフに送信され、承認待ちの状態になりました。承認された場合、このサイトの<a href=\"{$_CONF['site_url']}/calendar/index.php\">カレンダ</a>セクションに表示されます。";
 $PLG_calendar_MESSAGE17 = 'イベントが保存されました。';
 $PLG_calendar_MESSAGE18 = 'イベントが削除されました。';
 $PLG_calendar_MESSAGE24 = 'イベントが個人カレンダに保存されました。';
@@ -223,16 +222,16 @@ $LANG_configsubgroups['calendar'] = array(
 
 $LANG_fs['calendar'] = array(
     'fs_main' => 'カレンダのメイン設定',
-    'fs_permissions' => 'カレンダのデフォルトパーミッション（[0]所有者 [1]グループ [2]メンバー [3]ゲスト）'
+    'fs_permissions' => 'カレンダのパーミッションのデフォルト（[0]所有者 [1]グループ [2]メンバー [3]ゲスト）'
 );
 
 // Note: entries 0, 1, 6, 9, 12 are the same as in $LANG_configselects['Core']
 $LANG_configselects['calendar'] = array(
     0 => array('はい' => 1, 'いいえ' => 0),
     1 => array('はい' => TRUE, 'いいえ' => FALSE),
-    6 => array('12' => '12', '24' => '24'),
+    6 => array('12' => 12, '24' => 24),
     9 => array('作成したイベントを表示する' => 'item', 'カレンダ管理を表示する' => 'list', 'カレンダを表示する' => 'plugin', 'ホームを表示する' => 'home', '管理画面トップを表示する' => 'admin'),
     12 => array('アクセス不可' => 0, '表示' => 2, '表示・編集' => 3)
 );
 
-?>
\ No newline at end of file
+?>
