@@ -56,7 +56,11 @@ $LANG_POLLS = array(
     'upgrade1' => 'Neue Version des Umfrage-Plugins installiert. Bitte',
     'upgrade2' => 'upgraden',
     'editinstructions' => 'Bitte fr die Umfrage-ID mindestens eine Frage und zwei Antworten eintragen.',
-    'start_poll' => 'Zur Umfrage'
+    'pollclosed' => 'Diese Umfrage ist abgeschlossen.',
+    'pollhidden' => 'Du hast schon abgestimmt. Die Ergebnisse dieser Umfrage werden verffentlicht, sobald sie abgeschlossen ist.',
+    'start_poll' => 'Zur Umfrage',
+    'no_new_polls' => 'Keine neuen Umfragen',
+    'deny_msg' => 'Zugang zu dieser Umfrage nicht gestattet.  Entweder wurde diese Umfrage entfernt oder es fehlen die ntigen Zugriffsrechte.'
 );
 
 ###############################################################################
@@ -86,7 +90,7 @@ $LANG25 = array(
     21 => 'Kein Zugang',
     22 => "You are trying to access a poll that you don't have rights to.  This attempt has been logged. Please <a href=\"{$_CONF['site_admin_url']}/poll.php\">go back to the poll administration screen</a>.",
     23 => 'Neue Umfrage',
-    24 => 'Kommandozentrale',
+    24 => 'Schaltzentrale',
     25 => 'Ja',
     26 => 'Nein',
     27 => 'Editieren',
@@ -105,6 +109,7 @@ $LANG25 = array(
     40 => 'Alle Antworten zu dieser Umfrage ansehen'
 );
 
+$PLG_polls_MESSAGE15 = 'Der Kommentar wurde gespeichert, muss aber noch von einem Moderator freigegeben werden.';
 $PLG_polls_MESSAGE19 = 'Umfrage wurde gespeichert.';
 $PLG_polls_MESSAGE20 = 'Umfrage wurde gelscht.';
 
@@ -119,16 +124,20 @@ $LANG_configsections['polls'] = array(
 );
 
 $LANG_confignames['polls'] = array(
-    'pollsloginrequired' => 'Zur Einsicht einloggen ntig?',
+    'pollsloginrequired' => 'Anmelden zur Einsicht ntig?',
     'hidepollsmenu' => 'Meneintrag ausblenden?',
     'maxquestions' => 'Max. Fragen pro Umfrage',
     'maxanswers' => 'Max. Mglichkeiten pro Frage',
     'answerorder' => 'Ergebnisse sortieren ...',
-    'pollcookietime' => 'Voter Cookie gltig fr',
-    'polladdresstime' => 'Voter IP-Adresse gltig fr',
+    'pollcookietime' => 'Cookie des Abstimmenden gltig fr',
+    'polladdresstime' => 'IP-Adresse des Abstimmenden gltig fr',
     'delete_polls' => 'Umfragen mit User lschen?',
     'aftersave' => 'Nach speichern der Umfrage',
-    'default_permissions' => 'Grundeinstellungen Umfragen'
+    'default_permissions' => 'Grundeinstellungen Umfragen',
+    'newpollsinterval' => 'Zeitabstand neue Umfragen',
+    'hidenewpolls' => 'Neue Umfragen',
+    'title_trim_length' => 'Titel abschneiden nach',
+    'meta_tags' => 'Meta-Tags verwenden'
 );
 
 $LANG_configsubgroups['polls'] = array(
@@ -137,6 +146,7 @@ $LANG_configsubgroups['polls'] = array(
 
 $LANG_fs['polls'] = array(
     'fs_main' => 'Allgemeine Umfrageeinstellungen',
+    'fs_whatsnew' => 'What\'s New Block',
     'fs_permissions' => 'Grundeinstellungen Rechte'
 );
 
@@ -145,8 +155,9 @@ $LANG_configselects['polls'] = array(
     0 => array('Ja' => 1, 'Nein' => 0),
     1 => array('Ja' => true, 'Nein' => false),
     2 => array('Wie eingereicht' => 'submitorder', 'Nach Abstimmung' => 'voteorder'),
-    9 => array('Zur Umfrage weiterleiten' => 'item', 'Admin Liste anzeigen' => 'list', 'ffentliche Liste anzeigen' => 'plugin', 'Startseite anzeigen' => 'home', 'Kommandozentrale' => 'admin'),
+    5 => array('Verbergen' => 'hide', 'Anzeigen - Modifiziertes Datum benutzen' => 'modified', 'Anzeigen - Datum der Erstellung benutzen' => 'created'),
+    9 => array('Zur Umfrage weiterleiten' => 'item', 'Admin Liste anzeigen' => 'list', 'ffentliche Liste anzeigen' => 'plugin', 'Startseite' => 'home', 'Schaltzentrale' => 'admin'),
     12 => array('Kein Zugang' => 0, 'Nur lesen' => 2, 'Lesen-Schreiben' => 3)
 );
 
-?>
\ No newline at end of file
+?>
