@@ -8,7 +8,7 @@
 // |                                                                           |
 // | Geeklog plugin administration page.                                       |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2009 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -69,7 +69,7 @@ if (!SEC_hasRights('plugin.edit')) {
     COM_output($display);
     exit;
 }
-
+       
 /**
 * Shows the plugin editor form
 *
@@ -173,29 +173,58 @@ function plugineditor($pi_name, $confirmed = 0)
 /**
 * Toggle plugin status from enabled to disabled and back
 *
-* @param    array   $pi_name_arr    array of plugin states
+* @param    array   $enabledplugins     array containing ids of enabled plugins
+* @param    array   $visibleplugins     array containing ids of visible plugins
 * @return   void
 *
 */
-function changePluginStatus($pi_name_arr)
+function changePluginStatus($enabledplugins, $visibleplugins)
 {
     global $_TABLES, $_DB_table_prefix;
 
-    // first, get a list of all plugins
-    $rst = DB_query("SELECT pi_name, pi_enabled FROM {$_TABLES['plugins']}");
-    $plg_count = DB_numRows($rst);
-    for ($i = 0; $i < $plg_count; $i++) { // iterate and check/change match with array
-        $P = DB_fetchArray($rst);
-        if (isset($pi_name_arr[$P['pi_name']]) && ($P['pi_enabled'] == 0)) { // enable it
-            PLG_enableStateChange($P['pi_name'], true);
+    $disabledplugins = array_diff($visibleplugins, $enabledplugins);
+
+    /**
+    * Since plugins require some more love when enabling / disabling, we need
+    * to figure out exactly which plugin was enabled or disabled and treat it
+    * accordingly.
+    */
+
+    $plugin_name = '';
+
+    // first, check for a newly enabled plugin
+    $in = implode("','", $enabledplugins);
+    if (! empty($in)) {
+        $sql = "SELECT pi_name FROM {$_TABLES['plugins']} WHERE pi_name IN ('{$in}') AND pi_enabled = 0";
+        $result = DB_query($sql);
+        if (DB_numRows($result) > 0) {
+            list($plugin_name) = DB_fetchArray($result);
+        }
+
+        if (! empty($plugin_name)) { // this plugin is to be enabled
+            PLG_enableStateChange($plugin_name, true);
             DB_change($_TABLES['plugins'], 'pi_enabled', 1,
-                                           'pi_name', $P['pi_name']);
-            PLG_pluginStateChange($P['pi_name'], 'enabled');
-        } elseif (!isset($pi_name_arr[$P['pi_name']]) && $P['pi_enabled'] == 1) {  // disable it
-            PLG_enableStateChange($P['pi_name'], false);
-            DB_change($_TABLES['plugins'], 'pi_enabled', 0,
-                                           'pi_name', $P['pi_name']);
-            PLG_pluginStateChange($P['pi_name'], 'disabled');
+                                           'pi_name', $plugin_name);
+            PLG_pluginStateChange($plugin_name, 'enabled');
+        }
+    }
+
+    // nothing found yet? check for a newly disabled plugin then
+    if (empty($plugin_name)) {
+        $in = implode("','", $disabledplugins);
+        if (! empty($in)) {
+            $sql = "SELECT pi_name FROM {$_TABLES['plugins']} WHERE pi_name IN ('{$in}') AND pi_enabled = 1";
+            $result = DB_query($sql);
+            if (DB_numRows($result) > 0) {
+                list($plugin_name) = DB_fetchArray($result);
+            }
+
+            if (! empty($plugin_name)) { // this plugin is to be disabled
+                PLG_enableStateChange($plugin_name, false);
+                DB_change($_TABLES['plugins'], 'pi_enabled', 0,
+                                               'pi_name', $plugin_name);
+                PLG_pluginStateChange($plugin_name, 'disabled');
+            }
         }
     }
 }
@@ -474,7 +503,12 @@ function listplugins($token)
 
     // this is a dummy variable so we know the form has been used if all plugins
     // should be disabled in order to disable the last one.
-    $form_arr = array('bottom' => '<input type="hidden" name="pluginenabler" value="true"' . XHTML . '>');
+    $form_arr = array(
+        'top'    => '<input type="hidden" name="' . CSRF_TOKEN . '" value="'
+                    . $token . '"' . XHTML . '>',
+        'bottom' => '<input type="hidden" name="pluginenabler" value="true"'
+                    . XHTML . '>'
+    );
 
     $retval .= ADMIN_list('plugins', 'ADMIN_getListField_plugins', $header_arr,
                 $text_arr, $query_arr, $defsort_arr, '', $token, '', $form_arr);
@@ -940,7 +974,14 @@ function plugin_do_autoinstall($plugin, $inst_parms, $verbose = true)
 
             $grp_name = addslashes($name);
             $grp_desc = addslashes($desc);
-            DB_query("INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr) VALUES ('$grp_name', '$grp_desc')", 1);
+            $sql=array();
+
+            $sql['pgsql']="INSERT INTO {$_TABLES['groups']} (grp_id,grp_name, grp_descr) VALUES ((SELECT NEXTVAL('{$_TABLES['groups']}_grp_id_seq')),'$grp_name', '$grp_desc')";
+            $sql['mysql']="INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr) VALUES ('$grp_name', '$grp_desc')";
+            $sql['mssql']="INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr) VALUES ('$grp_name', '$grp_desc')";
+           
+            
+            DB_query($sql,1);
             if (DB_error()) {
                 COM_errorLog('Error creating plugin group', 1);
                 PLG_uninstall($plugin);
@@ -1004,8 +1045,18 @@ function plugin_do_autoinstall($plugin, $inst_parms, $verbose = true)
         foreach ($features as $feature => $desc) {
             $ft_name = addslashes($feature);
             $ft_desc = addslashes($desc);
-            DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
-                     . "VALUES ('$ft_name', '$ft_desc')", 1);
+            $sql=array();
+            
+             $sql['pgsql']="INSERT INTO {$_TABLES['features']} (ft_id,ft_name, ft_descr)
+                     VALUES ((SELECT nextval('{$_TABLES['features']}_ft_id_seq')),'$ft_name', '$ft_desc')"; 
+                       
+             $sql['mysql']="INSERT INTO {$_TABLES['features']} (ft_name, ft_descr)
+                    VALUES ('$ft_name', '$ft_desc')";
+                    
+             $sql['mysql']="INSERT INTO {$_TABLES['features']} (ft_name, ft_descr)
+                    VALUES ('$ft_name', '$ft_desc')";
+            
+            DB_query($sql,1);
             if (DB_error()) {
                 COM_errorLog('Error adding plugin feature', 1);
                 PLG_uninstall($plugin);
@@ -1172,11 +1223,15 @@ if (isset($_POST['pluginenabler'])) { // JavaScript-triggered POST request
         $_POST['mode'] = $LANG32[34];
         $_POST['pi_name'] = $_POST['updatethisplugin'];
     } elseif (SEC_checkToken()) {
+        $enabledplugins = array();
         if (isset($_POST['enabledplugins'])) {
-            changePluginStatus($_POST['enabledplugins']);
-        } else {
-            changePluginStatus(array());
+            $enabledplugins = $_POST['enabledplugins'];
         }
+        $visibleplugins = array();
+        if (isset($_POST['visibleplugins'])) {
+            $visibleplugins = $_POST['visibleplugins'];
+        }
+        changePluginStatus($enabledplugins, $visibleplugins);
 
         // force a refresh so that the information of the plugin that was just
         // enabled / disabled (menu entries, etc.) is displayed properly
