@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.5                                                               |
+// | Geeklog 1.6                                                               |
 // +---------------------------------------------------------------------------+
 // | story.php                                                                 |
 // |                                                                           |
 // | Geeklog story administration page.                                        |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2008 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -31,14 +31,12 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: story.php,v 1.270 2008/09/13 07:26:43 mjervis Exp $
 
 /**
 * This is the Geeklog story administration page.
 *
 * @author   Jason Whittenburg
-* @author   Tony Bibbs <tony AT tonybibbs DOT com>
+* @author   Tony Bibbs, tony AT tonybibbs DOT com
 *
 */
 
@@ -46,13 +44,17 @@
 * Geeklog common function library
 */
 require_once '../lib-common.php';
-require_once $_CONF['path_system'] . 'lib-story.php';
 
 /**
 * Security check to ensure user even belongs on this page
 */
 require_once 'auth.inc.php';
 
+/**
+* Geeklog story function library
+*/
+require_once $_CONF['path_system'] . 'lib-story.php';
+
 // Set this to true if you want to have this code output debug messages to
 // the error log
 $_STORY_VERBOSE = false;
@@ -60,14 +62,11 @@ $_STORY_VERBOSE = false;
 $display = '';
 
 if (!SEC_hasRights('story.edit')) {
-    $display .= COM_siteHeader ('menu', $MESSAGE[30]);
-    $display .= COM_startBlock ($MESSAGE[30], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-    $display .= $MESSAGE[31];
-    $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-    $display .= COM_siteFooter ();
+    $display .= COM_siteHeader('menu', $MESSAGE[30])
+             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
+             . COM_siteFooter();
     COM_accessLog("User {$_USER['username']} tried to illegally access the story administration screen.");
-    echo $display;
+    COM_output($display);
     exit;
 }
 
@@ -104,7 +103,14 @@ function userlist ($uid = 0)
     return $retval;
 }
 
-function liststories()
+/**
+* Provide list of stories
+*
+* @param    string  $current_topic  (optional) currently selected topic
+* @return   string                  HTML for the list of stories
+*
+*/
+function liststories($current_topic = '')
 {
     global $_CONF, $_TABLES, $_IMAGE_TYPE,
            $LANG09, $LANG_ADMIN, $LANG_ACCESS, $LANG24;
@@ -113,40 +119,40 @@ function liststories()
 
     $retval = '';
 
-    if (!empty ($_GET['tid'])) {
-        $current_topic = COM_applyFilter($_GET['tid']);
-    } elseif (!empty ($_POST['tid'])) {
-        $current_topic = COM_applyFilter($_POST['tid']);
-    } else {
+    if (empty($current_topic)) {
         $current_topic = $LANG09[9];
     }
 
-    if ($current_topic == $LANG09[9]) {
+    if ($current_topic == $LANG09[9]) { // "All"
         $excludetopics = '';
         $seltopics = '';
-        $topicsql = "SELECT tid,topic FROM {$_TABLES['topics']}" . COM_getPermSQL ();
-        $tresult = DB_query( $topicsql );
-        $trows = DB_numRows( $tresult );
-        if( $trows > 0 )
-        {
-            $excludetopics .= ' (';
-            for( $i = 1; $i <= $trows; $i++ )  {
-                $T = DB_fetchArray ($tresult);
-                if ($i > 1)  {
-                    $excludetopics .= ' OR ';
-                }
-                $excludetopics .= "tid = '{$T['tid']}'";
-                $seltopics .= '<option value="' .$T['tid']. '"';
-                if ($current_topic == "{$T['tid']}") {
+        $topicsql = "SELECT tid,topic FROM {$_TABLES['topics']}"
+                  . COM_getPermSQL ();
+        $tresult = DB_query($topicsql);
+        $trows = DB_numRows($tresult);
+        if ($trows > 0) {
+            $exclude = array();
+            for ($i = 0; $i < $trows; $i++)  {
+                $T = DB_fetchArray($tresult);
+                $exclude[] = $T['tid'];
+                $seltopics .= '<option value="' . $T['tid'] . '"';
+                if ($current_topic == $T['tid']) {
                     $seltopics .= ' selected="selected"';
                 }
                 $seltopics .= '>' . $T['topic'] . '</option>' . LB;
             }
-            $excludetopics .= ') ';
+            $excludetopics = " (tid IN ('" . implode( "','", $exclude ) . "')) ";
+        } else {
+            $retval .= COM_showMessage(101);
+            return $retval;
         }
     } else {
         $excludetopics = " tid = '$current_topic' ";
-        $seltopics = COM_topicList ('tid,topic', $current_topic, 1, true);
+        $seltopics = COM_topicList('tid,topic', $current_topic, 1, true);
+        if (empty($seltopics)) {
+            $retval .= COM_showMessage(101);
+            return $retval;
+        }
     }
 
     $alltopics = '<option value="' .$LANG09[9]. '"';
@@ -159,13 +165,18 @@ function liststories()
         . $alltopics . $seltopics . '</select>';
 
     $header_arr = array(
-        array('text' => $LANG_ADMIN['edit'], 'field' => 'edit', 'sort' => false));
-
-    $header_arr[] = array('text' => $LANG_ADMIN['title'], 'field' => 'title', 'sort' => true);
-    $header_arr[] = array('text' => $LANG_ACCESS['access'], 'field' => 'access', 'sort' => false);
-    $header_arr[] = array('text' => $LANG24[34], 'field' => 'draft_flag', 'sort' => true);
-    $header_arr[] = array('text' => $LANG24[7], 'field' => 'username', 'sort' => true); //author
-    $header_arr[] = array('text' => $LANG24[15], 'field' => 'unixdate', 'sort' => true); //date
+        array('text' => $LANG_ADMIN['edit'], 'field' => 'edit', 'sort' => false),
+        array('text' => $LANG_ADMIN['copy'], 'field' => 'copy', 'sort' => false),
+        array('text' => $LANG_ADMIN['title'], 'field' => 'title', 'sort' => true),
+        array('text' => $LANG_ACCESS['access'], 'field' => 'access', 'sort' => false),
+        array('text' => $LANG24[34], 'field' => 'draft_flag', 'sort' => true)
+    );
+    if ($_CONF['show_fullname'] == 1) {
+        $header_arr[] = array('text' => $LANG24[7], 'field' => 'fullname', 'sort' => true); // author
+    } else {
+        $header_arr[] = array('text' => $LANG24[7], 'field' => 'username', 'sort' => true); // author
+    }
+    $header_arr[] = array('text' => $LANG24[15], 'field' => 'unixdate', 'sort' => true); // date
     $header_arr[] = array('text' => $LANG_ADMIN['topic'], 'field' => 'tid', 'sort' => true);
     $header_arr[] = array('text' => $LANG24[32], 'field' => 'featured', 'sort' => true);
 
@@ -177,12 +188,12 @@ function liststories()
     $defsort_arr = array('field' => 'unixdate', 'direction' => 'desc');
 
     $menu_arr = array (
-        array('url' => $_CONF['site_admin_url'] . '/story.php?mode=edit&amp;editor=std',
+        array('url' => $_CONF['site_admin_url'] . '/story.php?mode=edit',
               'text' => $LANG_ADMIN['create_new'])
     );
 
     $menu_arr[] = array('url' => $_CONF['site_admin_url'],
-                          'text' => $LANG_ADMIN['admin_home']);
+                        'text' => $LANG_ADMIN['admin_home']);
 
     $retval .= COM_startBlock($LANG24[22], '',
                               COM_getBlockTemplate('_admin_block', 'header'));
@@ -209,7 +220,7 @@ function liststories()
         'table' => 'stories',
         'sql' => $sql,
         'query_fields' => array('title', 'introtext', 'bodytext', 'sid', 'tid'),
-        'default_filter' => $excludetopics . COM_getPermSQL ('AND')
+        'default_filter' => $excludetopics . COM_getPermSQL('AND')
     );
 
     $retval .= ADMIN_list('story', 'ADMIN_getListField_stories', $header_arr,
@@ -225,7 +236,7 @@ function liststories()
 * Displays the story entry form
 *
 * @param    string      $sid            ID of story to edit
-* @param    string      $mode           'preview', 'edit', 'editsubmission'
+* @param    string      $mode           'preview', 'edit', 'editsubmission', 'clone'
 * @param    string      $errormsg       a message to display on top of the page
 * @param    string      $currenttopic   topic selection for drop-down menu
 * @return   string      HTML for story editor
@@ -233,8 +244,8 @@ function liststories()
 */
 function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
 {
-    global $_CONF, $_GROUPS, $_TABLES, $_USER, $LANG24, $LANG_ACCESS,
-           $LANG_ADMIN, $MESSAGE;
+    global $_CONF, $_TABLES, $_USER, $LANG24, $LANG_ACCESS, $LANG_ADMIN,
+           $MESSAGE;
 
     $display = '';
 
@@ -260,8 +271,17 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     }
 
     $story = new Story();
-    if($mode == 'preview')
-    {
+    if ($mode == 'preview') {
+        // Handle Magic GPC Garbage:
+        while (list($key, $value) = each($_POST)) {
+            if (!is_array($value)) {
+                $_POST[$key] = COM_stripslashes($value);
+            } else {
+                while (list($subkey, $subvalue) = each($value)) {
+                    $value[$subkey] = COM_stripslashes($subvalue);
+                }
+            }
+        }
         $result = $story->loadFromArgsArray($_POST);
     } else {
         $result = $story->loadFromDatabase($sid, $mode);
@@ -280,7 +300,7 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
                                 COM_getBlockTemplate ('_msg_block', 'header'));
         $display .= $LANG24[41];
         $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-        $display .= STORY_renderArticle ($A, 'p');
+        $display .= STORY_renderArticle ($story, 'p');
         COM_accessLog("User {$_USER['username']} tried to illegally edit story $sid.");
         return $display;
     } elseif( $result == STORY_INVALID_SID ) {
@@ -293,20 +313,17 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
             return COM_refresh( $_CONF['site_admin_url'] . '/story.php' );
         }
     } elseif( $result == STORY_DUPLICATE_SID) {
-        $display .= COM_errorLog ($LANG24[24], 2);
+        $display .= COM_showMessageText($LANG24[24]);
     }
 
     // Load HTML templates
     $story_templates = new Template($_CONF['path_layout'] . 'admin/story');
-    if ( isset ($_CONF['advanced_editor']) && ($_CONF['advanced_editor'] == 1 )
-        && file_exists ($_CONF['path_layout'] . 'admin/story/storyeditor_advanced.thtml')) {
-        $advanced_editormode = true;
+    if ($_CONF['advanced_editor'] && $_USER['advanced_editor']) {
         $story_templates->set_file(array('editor'=>'storyeditor_advanced.thtml'));
-        $story_templates->set_var ( 'xhtml', XHTML );
+        $advanced_editormode = true;
         $story_templates->set_var ('change_editormode', 'onchange="change_editmode(this);"');
 
         require_once $_CONF['path_system'] . 'classes/navbar.class.php';
-
         $story_templates->set_var ('show_preview', 'none');
         $story_templates->set_var ('lang_expandhelp', $LANG24[67]);
         $story_templates->set_var ('lang_reducehelp', $LANG24[68]);
@@ -326,21 +343,27 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
             $story_templates->set_var ('show_htmleditor', 'none');
         }
     } else {
-        $story_templates->set_file(array('editor' => 'storyeditor.thtml'));
-        $story_templates->set_var('xhtml', XHTML);
+        $thtml = $_CONF['path_layout'] . 'admin/story/storyeditor.' . $_CONF['language'] . '.thtml';
+        if (file_exists($thtml)) {
+            $thtml = 'storyeditor.' . $_CONF['language'] . '.thtml';
+        } else {
+            $thtml = 'storyeditor.thtml';
+        }
+        $story_templates->set_file(array('editor' => $thtml));
         $advanced_editormode = false;
     }
-    $story_templates->set_var ('site_url',       $_CONF['site_url']);
-    $story_templates->set_var ('site_admin_url', $_CONF['site_admin_url']);
-    $story_templates->set_var ('layout_url',     $_CONF['layout_url']);
-    $story_templates->set_var ('hour_mode',      $_CONF['hour_mode']);
+    $story_templates->set_var('xhtml', XHTML);
+    $story_templates->set_var('site_url',       $_CONF['site_url']);
+    $story_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
+    $story_templates->set_var('layout_url',     $_CONF['layout_url']);
+    $story_templates->set_var('hour_mode',      $_CONF['hour_mode']);
 
     if ($story->hasContent()) {
         $previewContent = STORY_renderArticle($story, 'p');
         if ($advanced_editormode AND $previewContent != '' ) {
             $story_templates->set_var('preview_content', $previewContent);
         } elseif ($previewContent != '') {
-            $display = COM_startBlock ($LANG24[26], '',
+            $display .= COM_startBlock ($LANG24[26], '',
                             COM_getBlockTemplate ('_admin_block', 'header'));
             $display .= $previewContent;
             $display .= COM_endBlock (COM_getBlockTemplate ('_admin_block', 'footer'));
@@ -365,15 +388,20 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
             $navbar->add_menuitem($LANG24[84],'showhideEditorDiv("perms",4);return false;',true);
             $navbar->add_menuitem($LANG24[85],'showhideEditorDiv("all",5);return false;',true);
         }
-
-        $navbar->set_selected($LANG24[80]);
+        if ($mode == 'preview') {
+            $story_templates->set_var ('show_preview', '');
+            $story_templates->set_var ('show_htmleditor', 'none');
+            $story_templates->set_var ('show_texteditor', 'none');
+            $story_templates->set_var ('show_submitoptions', 'none');
+            $navbar->set_selected($LANG24[79]);
+        } else {
+            $navbar->set_selected($LANG24[80]);
+        }
         $story_templates->set_var ('navbar', $navbar->generate() );
     }
 
-    $display .= COM_startBlock ($LANG24[5], '',
-                        COM_getBlockTemplate ('_admin_block', 'header'));
     $oldsid = $story->EditElements('originalSid');
-    if (!empty ($oldsid)) {
+    if (!empty ($oldsid) && $mode != 'clone') {
         $delbutton = '<input type="submit" value="' . $LANG_ADMIN['delete']
                    . '" name="mode"%s' . XHTML . '>';
         $jsconfirm = ' onclick="return confirm(\'' . $MESSAGE[76] . '\');"';
@@ -411,6 +439,7 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         $story->EditElements('perm_owner'),$story->EditElements('perm_group'),
         $story->EditElements('perm_members'),$story->EditElements('perm_anon')));
     $story_templates->set_var('permissions_msg', $LANG_ACCESS['permmsg']);
+    $story_templates->set_var('lang_permissions_msg', $LANG_ACCESS['permmsg']);
     $curtime = COM_getUserDateTimeFormat($story->EditElements('date'));
     $story_templates->set_var('lang_date', $LANG24[15]);
 
@@ -491,42 +520,65 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
 
     $story_templates->set_var('expire_date_explanation', $LANG24[46]);
     $story_templates->set_var('story_unixstamp', $story->EditElements('expirestamp'));
+
+    $atopic = DB_getItem($_TABLES['topics'], 'tid', "archive_flag = 1");
+    $have_archive_topic = (empty($atopic) ? false : true);
+
     if ($story->EditElements('statuscode') == STORY_ARCHIVE_ON_EXPIRE) {
         $story_templates->set_var('is_checked2', 'checked="checked"');
         $story_templates->set_var('is_checked3', 'checked="checked"');
         $story_templates->set_var('showarchivedisabled', 'false');
+        $have_archive_topic = true; // force display of auto archive option
     } elseif ($story->EditElements('statuscode') == STORY_DELETE_ON_EXPIRE) {
         $story_templates->set_var('is_checked2', 'checked="checked"');
         $story_templates->set_var('is_checked4', 'checked="checked"');
+        if (! $have_archive_topic) {
+            $story_templates->set_var('is_checked3', 'style="display:none;"');
+        }
         $story_templates->set_var('showarchivedisabled', 'false');
     } else {
+        if (! $have_archive_topic) {
+            $story_templates->set_var('is_checked3', 'style="display:none;"');
+        }
         $story_templates->set_var('showarchivedisabled', 'true');
     }
     $story_templates->set_var('lang_archivetitle', $LANG24[58]);
     $story_templates->set_var('lang_option', $LANG24[59]);
     $story_templates->set_var('lang_enabled', $LANG_ADMIN['enabled']);
     $story_templates->set_var('lang_story_stats', $LANG24[87]);
-    $story_templates->set_var('lang_optionarchive', $LANG24[61]);
+    if ($have_archive_topic) {
+        $story_templates->set_var('lang_optionarchive', $LANG24[61]);
+    } else {
+        $story_templates->set_var('lang_optionarchive', '');
+    }
     $story_templates->set_var('lang_optiondelete', $LANG24[62]);
     $story_templates->set_var('lang_title', $LANG_ADMIN['title']);
-//    if ($A['postmode'] == 'plaintext') {
-//        $A['title'] = str_replace ('$', '&#36;', $A['title']);
-//    }
-//
-//    $A['title'] = str_replace('{','&#123;',$A['title']);
-//    $A['title'] = str_replace('}','&#125;',$A['title']);
-//    $A['title'] = str_replace('"','&quot;',$A['title']);
-    $story_templates->set_var('story_title', $story->EditElements('title'));//stripslashes ($A['title']));
+    $story_templates->set_var('story_title', $story->EditElements('title'));
+    $story_templates->set_var('lang_page_title', $LANG_ADMIN['page_title']);
+    $story_templates->set_var('page_title' , $story->EditElements('page_title'));
+    $story_templates->set_var('lang_metadescription', $LANG_ADMIN['meta_description']);
+    $story_templates->set_var('meta_description', $story->EditElements('meta_description'));
+    $story_templates->set_var('lang_metakeywords', $LANG_ADMIN['meta_keywords']);
+    $story_templates->set_var('meta_keywords', $story->EditElements('meta_keywords'));
+    if ($_CONF['meta_tags'] > 0) {
+        $story_templates->set_var('hide_meta', '');
+    } else {
+        $story_templates->set_var('hide_meta', ' style="display:none;"');
+    }
     $story_templates->set_var('lang_topic', $LANG_ADMIN['topic']);
-    if(empty($currenttopic) && ($story->EditElements('tid') == ''))
-    {
-        $story->setTid( DB_getItem ($_TABLES['topics'], 'tid',
-                                'is_default = 1' . COM_getPermSQL ('AND')));
-    } else if ($story->EditElements('tid') == '') {
+    if(empty($currenttopic) && ($story->EditElements('tid') == '')) {
+        $story->setTid(DB_getItem($_TABLES['topics'], 'tid',
+                                  'is_default = 1' . COM_getPermSQL('AND')));
+    } elseif ($story->EditElements('tid') == '') {
         $story->setTid($currenttopic);
     }
-    $story_templates->set_var ('topic_options',
-                               COM_topicList ('tid,topic', $story->EditElements('tid'), 1, true));
+
+    $tlist = COM_topicList('tid,topic', $story->EditElements('tid'), 1, true);
+    if (empty($tlist)) {
+        $display .= COM_showMessage(101);
+        return $display;
+    }
+    $story_templates->set_var('topic_options', $tlist);
     $story_templates->set_var('lang_show_topic_icon', $LANG24[56]);
     if ($story->EditElements('show_topic_icon') == 1) {
         $story_templates->set_var('show_topic_icon_checked', 'checked="checked"');
@@ -547,6 +599,64 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     $story_templates->set_var ('trackback_options',
             COM_optionList ($_TABLES['trackbackcodes'], 'code,name',
                             $story->EditElements('trackbackcode')));
+    // comment expire
+    $story_templates->set_var('lang_cmt_disable', $LANG24[63]);
+    if ($story->EditElements('cmt_close')) {
+        $story_templates->set_var('is_checked5', 'checked="checked"');
+        $story_templates->set_var('showcmtclosedisabled', 'false');
+    } else {
+        $story_templates->set_var('showcmtclosedisabled', 'true');
+    }
+
+    $month_options = COM_getMonthFormOptions($story->EditElements('cmt_close_month'));
+    $story_templates->set_var('cmt_close_month_options', $month_options);
+
+    $day_options = COM_getDayFormOptions($story->EditElements('cmt_close_day'));
+    $story_templates->set_var('cmt_close_day_options', $day_options);
+
+    // ensure that the year dropdown includes the close year
+    $endtm = mktime(0, 0, 0, date('m'),
+                date('d') + $_CONF['article_comment_close_days'], date('Y'));
+    $yoffset = date('Y', $endtm) - date('Y');
+    $close_year = $story->EditElements('cmt_close_year');
+    if ($yoffset < -1) {
+        $year_options = COM_getYearFormOptions($close_year, $yoffset);
+    } elseif ($yoffset > 5) {
+        $year_options = COM_getYearFormOptions($close_year, -1, $yoffset);
+    } else {
+        $year_options = COM_getYearFormOptions($close_year);
+    }
+    $story_templates->set_var('cmt_close_year_options', $year_options);
+
+    $cmt_close_ampm = '';
+    $cmt_close_hour = $story->EditElements('cmt_close_hour');
+    //correct hour
+    if ($cmt_close_hour >= 12) {
+        if ($cmt_close_hour > 12) {
+            $cmt_close_hour = $cmt_close_hour - 12;
+        }
+        $ampm = 'pm';
+    } else {
+        $ampm = 'am';
+    }
+    $ampm_select = COM_getAmPmFormSelection ('cmt_close_ampm', $ampm);
+    if (empty ($ampm_select)) {
+        // have a hidden field to 24 hour mode to prevent JavaScript errors
+        $ampm_select = '<input type="hidden" name="cmt_close_ampm" value=""' . XHTML . '>';
+    }
+    $story_templates->set_var ('cmt_close_ampm_selection', $ampm_select);
+
+    if ($_CONF['hour_mode'] == 24) {
+        $hour_options = COM_getHourFormOptions ($story->EditElements('cmt_close_hour'), 24);
+    } else {
+        $hour_options = COM_getHourFormOptions ($cmt_close_hour);
+    }
+    $story_templates->set_var('cmt_close_hour_options', $hour_options);
+
+    $minute_options = COM_getMinuteFormOptions($story->EditElements('cmt_close_minute'));
+    $story_templates->set_var('cmt_close_minute_options', $minute_options);
+
+    $story_templates->set_var('cmt_close_second', $story->EditElements('cmt_close_second'));
 
     if (($_CONF['onlyrootfeatures'] == 1 && SEC_inGroup('Root'))
         or ($_CONF['onlyrootfeatures'] !== 1)) {
@@ -573,7 +683,7 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     $post_options = COM_optionList($_TABLES['postmodes'],'code,name',$story->EditElements('postmode'));
 
     // If Advanced Mode - add post option and set default if editing story created with Advanced Editor
-    if ($_CONF['advanced_editor'] == 1) {
+    if ($_CONF['advanced_editor'] && $_USER['advanced_editor']) {
         if ($story->EditElements('advanced_editor_mode') == 1 OR $story->EditElements('postmode') == 'adveditor') {
             $post_options .= '<option value="adveditor" selected="selected">'.$LANG24[86].'</option>';
         } else {
@@ -588,7 +698,8 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
         }
     }
     $story_templates->set_var('post_options',$post_options );
-    $story_templates->set_var('lang_allowed_html', COM_allowedHTML());
+    $story_templates->set_var('lang_allowed_html',
+                              COM_allowedHTML('story.edit'));
     $fileinputs = '';
     $saved_images = '';
     if ($_CONF['maximagesperarticle'] > 0) {
@@ -631,18 +742,29 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
     $story_templates->set_var('story_trackbacks', $story->EditElements('trackbacks'));
     $story_templates->set_var('lang_emails', $LANG24[39]);
     $story_templates->set_var('story_emails', $story->EditElements('numemails'));
-    $story_templates->set_var('story_id', $story->getSid());
-    $story_templates->set_var('old_story_id', $story->EditElements('originalSid'));
+    if ($mode == 'clone') {
+        $story_templates->set_var('story_id', COM_makesid());
+    } else {
+        $story_templates->set_var('story_id', $story->getSid());
+        $story_templates->set_var('old_story_id', $story->EditElements('originalSid'));
+    }
+
     $story_templates->set_var('lang_sid', $LANG24[12]);
     $story_templates->set_var('lang_save', $LANG_ADMIN['save']);
     $story_templates->set_var('lang_preview', $LANG_ADMIN['preview']);
     $story_templates->set_var('lang_cancel', $LANG_ADMIN['cancel']);
     $story_templates->set_var('lang_delete', $LANG_ADMIN['delete']);
     $story_templates->set_var('gltoken_name', CSRF_TOKEN);
-    $story_templates->set_var('gltoken', SEC_createToken());
+    $token = SEC_createToken();
+    $story_templates->set_var('gltoken', $token);
     $story_templates->parse('output','editor');
+
+    $display .= COM_startBlock($LANG24[5], '',
+                        COM_getBlockTemplate('_admin_block', 'header'));
+    $display .= SEC_getTokenExpiryNotice($token, $LANG24[91]);
+
     $display .= $story_templates->finish($story_templates->get_var('output'));
-    $display .= COM_endBlock (COM_getBlockTemplate ('_admin_block', 'footer'));
+    $display .= COM_endBlock(COM_getBlockTemplate('_admin_block', 'footer'));
 
     return $display;
 }
@@ -655,6 +777,7 @@ function storyeditor($sid = '', $mode = '', $errormsg = '', $currenttopic = '')
 * @param    int         $uid            ID of user that wrote the story
 * @param    string      $tid            Topic ID story belongs to
 * @param    string      $title          Title of story
+* @param    string      $page_title     Title of the page
 * @param    string      $introtext      Introduction text
 * @param    string      $bodytext       Text of body
 * @param    int         $hits           Number of times story has been viewed
@@ -743,15 +866,10 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
     }
 } else if (($mode == $LANG_ADMIN['preview']) && !empty ($LANG_ADMIN['preview'])) {
     $display .= COM_siteHeader('menu', $LANG24[5]);
-    $editor = '';
-    if (!empty ($_GET['editor'])) {
-        $editor = COM_applyFilter ($_GET['editor']);
-    }
-    $display .= storyeditor (COM_applyFilter ($_POST['sid']), 'preview', '', '',
-                             $editor);
+    $display .= storyeditor(COM_applyFilter($_POST['sid']), 'preview', '', '');
     $display .= COM_siteFooter();
-    echo $display;
-} else if ($mode == 'edit') {
+    COM_output($display);
+} elseif (($mode == 'edit') || ($mode == 'clone')) {
     $display .= COM_siteHeader('menu', $LANG24[5]);
     $sid = '';
     if (isset ($_GET['sid'])) {
@@ -761,39 +879,39 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
     if (isset ($_GET['topic'])) {
         $topic = COM_applyFilter ($_GET['topic']);
     }
-    $editor = '';
-    if (isset ($_GET['editor'])) {
-        $editor = COM_applyFilter ($_GET['editor']);
-    }
-    $display .= storyeditor ($sid, $mode, '', $topic, $editor);
+    $display .= storyeditor($sid, $mode, '', $topic);
     $display .= COM_siteFooter();
-    echo $display;
+    COM_output($display);
 } else if ($mode == 'editsubmission') {
     $display .= COM_siteHeader('menu', $LANG24[5]);
     $display .= storyeditor (COM_applyFilter ($_GET['id']), $mode);
     $display .= COM_siteFooter();
-    echo $display;
+    COM_output($display);
 } else if (($mode == $LANG_ADMIN['save']) && !empty ($LANG_ADMIN['save']) && SEC_checkToken()) {
     submitstory ();
 } else { // 'cancel' or no mode at all
     $type = '';
-    if (isset($_POST['type'])){
-        $type = COM_applyFilter ($_POST['type']);
+    if (isset($_POST['type'])) {
+        $type = COM_applyFilter($_POST['type']);
     }
-    if (($mode == $LANG24[10]) && !empty ($LANG24[10]) &&
+    if (($mode == $LANG24[10]) && !empty($LANG24[10]) &&
             ($type == 'submission')) {
-        $display = COM_refresh ($_CONF['site_admin_url'] . '/moderation.php');
+        $display = COM_refresh($_CONF['site_admin_url'] . '/moderation.php');
     } else {
-        $display .= COM_siteHeader('menu', $LANG24[22]);
-        $msg = "";
-        if (isset($_GET['msg'])) {
-            $msg = COM_applyFilter($_GET['msg'], true);
-            $display .= COM_showMessage($msg);
+        $current_topic = '';
+        if (empty($mode)) {
+            if (!empty ($_GET['tid'])) {
+                $current_topic = COM_applyFilter($_GET['tid']);
+            } elseif (!empty ($_POST['tid'])) {
+                $current_topic = COM_applyFilter($_POST['tid']);
+            }
         }
-        $display .= liststories();
+        $display .= COM_siteHeader('menu', $LANG24[22]);
+        $display .= COM_showMessageFromParameter();
+        $display .= liststories($current_topic);
         $display .= COM_siteFooter();
     }
-    echo $display;
+    COM_output($display);
 }
 
 ?>
