@@ -2,14 +2,14 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.6                                                               |
+// | Geeklog 1.7                                                               |
 // +---------------------------------------------------------------------------+
 // | profiles.php                                                              |
 // |                                                                           |
 // | This pages lets GL users communicate with each other without risk of      |
 // | their email address being intercepted by spammers.                        |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2009 by the following authors:                         |
+// | Copyright (C) 2000-2010 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
 // |          Mark Limburg      - mlimburg AT users DOT sourceforge DOT net    |
@@ -109,7 +109,7 @@ function contactemail($uid,$author,$authoremail,$subject,$message)
 
             $msg = PLG_itemPreSave ('contact', $message);
             if (!empty ($msg)) {
-                $retval .= COM_siteHeader ('menu', '')
+                $retval .= COM_siteHeader ('menu', $LANG04[81])
                         . COM_errorLog ($msg, 2)
                         . contactform ($uid, $subject, $message)
                         . COM_siteFooter ();
@@ -175,26 +175,13 @@ function contactemail($uid,$author,$authoremail,$subject,$message)
 */
 function contactform ($uid, $subject = '', $message = '')
 {
-    global $_CONF, $_TABLES, $_USER, $LANG08, $LANG_LOGIN;
+    global $_CONF, $_TABLES, $_USER, $LANG08;
 
     $retval = '';
 
     if (COM_isAnonUser() && (($_CONF['loginrequired'] == 1) ||
                              ($_CONF['emailuserloginrequired'] == 1))) {
-        $retval = COM_startBlock ($LANG_LOGIN[1], '',
-                          COM_getBlockTemplate ('_msg_block', 'header'));
-        $login = new Template($_CONF['path_layout'] . 'submit');
-        $login->set_file (array ('login'=>'submitloginrequired.thtml'));
-        $login->set_var ( 'xhtml', XHTML );
-        $login->set_var ('site_url', $_CONF['site_url']);
-        $login->set_var ('site_admin_url', $_CONF['site_admin_url']);
-        $login->set_var ('layout_url', $_CONF['layout_url']);
-        $login->set_var ('login_message', $LANG_LOGIN[2]);
-        $login->set_var ('lang_login', $LANG_LOGIN[3]);
-        $login->set_var ('lang_newuser', $LANG_LOGIN[4]);
-        $login->parse ('output', 'login');
-        $retval .= $login->finish ($login->get_var('output'));
-        $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+        $retval .= SEC_loginRequiredForm();
     } else {
         $result = DB_query ("SELECT emailfromadmin,emailfromuser FROM {$_TABLES['userprefs']} WHERE uid = '$uid'");
         $P = DB_fetchArray ($result);
@@ -208,13 +195,15 @@ function contactform ($uid, $subject = '', $message = '')
         if ((($P['emailfromadmin'] == 1) && $isAdmin) ||
             (($P['emailfromuser'] == 1) && !$isAdmin)) {
 
-            $retval = COM_startBlock ($LANG08[10] . ' ' . $displayname);
-            $mail_template = new Template ($_CONF['path_layout'] . 'profiles');
-            $mail_template->set_file ('form', 'contactuserform.thtml');
-            $mail_template->set_var ( 'xhtml', XHTML );
-            $mail_template->set_var ('site_url', $_CONF['site_url']);
-            $mail_template->set_var ('lang_description', $LANG08[26]);
-            $mail_template->set_var ('lang_username', $LANG08[11]);
+            $retval = COM_startBlock($LANG08[10] . ' ' . $displayname);
+            $mail_template = new Template($_CONF['path_layout'] . 'profiles');
+            $mail_template->set_file('form', 'contactuserform.thtml');
+            $mail_template->set_var('xhtml', XHTML);
+            $mail_template->set_var('site_url', $_CONF['site_url']);
+            $mail_template->set_var('site_admin_url', $_CONF['site_admin_url']);
+            $mail_template->set_var('layout_url', $_CONF['layout_url']);
+            $mail_template->set_var('lang_description', $LANG08[26]);
+            $mail_template->set_var('lang_username', $LANG08[11]);
             if (COM_isAnonUser()) {
                 $sender = '';
                 if (isset ($_POST['author'])) {
@@ -408,7 +397,7 @@ function mailstory($sid, $to, $toemail, $from, $fromemail, $shortmsg)
 function mailstoryform ($sid, $to = '', $toemail = '', $from = '',
                         $fromemail = '', $shortmsg = '', $msg = 0)
 {
-    global $_CONF, $_TABLES, $_USER, $LANG08, $LANG_LOGIN;
+    global $_CONF, $_TABLES, $_USER, $LANG08;
 
     require_once $_CONF['path_system'] . 'lib-story.php';
 
@@ -416,20 +405,7 @@ function mailstoryform ($sid, $to = '', $toemail = '', $from = '',
 
     if (COM_isAnonUser() && (($_CONF['loginrequired'] == 1) ||
                              ($_CONF['emailstoryloginrequired'] == 1))) {
-        $retval = COM_startBlock ($LANG_LOGIN[1], '',
-                          COM_getBlockTemplate ('_msg_block', 'header'));
-        $login = new Template($_CONF['path_layout'] . 'submit');
-        $login->set_file (array ('login'=>'submitloginrequired.thtml'));
-        $login->set_var ( 'xhtml', XHTML );
-        $login->set_var ('site_url', $_CONF['site_url']);
-        $login->set_var ('site_admin_url', $_CONF['site_admin_url']);
-        $login->set_var ('layout_url', $_CONF['layout_url']);
-        $login->set_var ('login_message', $LANG_LOGIN[2]);
-        $login->set_var ('lang_login', $LANG_LOGIN[3]);
-        $login->set_var ('lang_newuser', $LANG_LOGIN[4]);
-        $login->parse ('output', 'login');
-        $retval .= $login->finish ($login->get_var('output'));
-        $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+        $retval .= SEC_loginRequiredForm();
 
         return $retval;
     }
